@@ -18,7 +18,7 @@
  */
 
 /*
-** Common definition between mysql server & client
+** Common definition between Drizzle server & client
 */
 
 #pragma once
@@ -77,12 +77,6 @@
 /** If not set then the thread will ignore all warnings with level notes. */
 #define OPTION_SQL_NOTES                (UINT64_C(1) << 31) // THD, user
 
-/**
-  Maximum length of time zone name that we support
-  (Time zone name is char(64) in db). mysqlbinlog needs it.
-*/
-#define MAX_TIME_ZONE_NAME_LENGTH       (NAME_LEN + 1)
-
 #define HOSTNAME_LENGTH 60
 #define SYSTEM_CHARSET_MBMAXLEN 4
 #define USERNAME_CHAR_LENGTH 16
@@ -166,7 +160,7 @@ enum enum_server_command
 {
   COM_SLEEP,
   COM_QUIT,
-  COM_INIT_DB,
+  COM_USE_SCHEMA,
   COM_QUERY,
   COM_SHUTDOWN,
   COM_CONNECT,
@@ -193,9 +187,10 @@ enum enum_field_types {
                         DRIZZLE_TYPE_TIME,
                         DRIZZLE_TYPE_BOOLEAN,
                         DRIZZLE_TYPE_UUID,
-                        DRIZZLE_TYPE_MICROTIME
+                        DRIZZLE_TYPE_MICROTIME,
+                        DRIZZLE_TYPE_IPV6
 };
-const int enum_field_types_size= DRIZZLE_TYPE_MICROTIME + 1;
+const int enum_field_types_size= DRIZZLE_TYPE_IPV6 + 1;
 
 } /* namespace drizzled */
 
