@@ -44,6 +44,9 @@
 #include <drizzled/transaction_services.h>
 #include <drizzled/key.h>
 #include <drizzled/sql_lex.h>
+#include <drizzled/resource_context.h>
+#include <drizzled/statistics_variables.h>
+#include <drizzled/system_variables.h>
 
 using namespace std;
 
@@ -65,9 +68,9 @@ Cursor::Cursor(plugin::StorageEngine &engine_arg,
     next_insert_id(0), insert_id_for_cur_row(0)
 { }
 
-Cursor::~Cursor(void)
+Cursor::~Cursor()
 {
-  assert(locked == false);
+  assert(not locked);
   /* TODO: assert(inited == NONE); */
 }
 
@@ -80,24 +83,14 @@ Cursor::~Cursor(void)
 Cursor *Cursor::clone(memory::Root *mem_root)
 {
   Cursor *new_handler= getTable()->getMutableShare()->db_type()->getCursor(*getTable());
-
   /*
     Allocate Cursor->ref here because otherwise ha_open will allocate it
     on this->table->mem_root and we will not be able to reclaim that memory
     when the clone Cursor object is destroyed.
   */
-  if (!(new_handler->ref= (unsigned char*) mem_root->alloc_root(ALIGN_SIZE(ref_length)*2)))
-    return NULL;
-
-  identifier::Table identifier(getTable()->getShare()->getSchemaName(),
-                             getTable()->getShare()->getTableName(),
-                             getTable()->getShare()->getType());
-
-  if (new_handler && !new_handler->ha_open(identifier,
-                                           getTable()->getDBStat(),
-                                           HA_OPEN_IGNORE_IF_LOCKED))
-    return new_handler;
-  return NULL;
+  new_handler->ref= mem_root->alloc(ALIGN_SIZE(ref_length)*2);
+  identifier::Table identifier(getTable()->getShare()->getSchemaName(), getTable()->getShare()->getTableName(), getTable()->getShare()->getType());
+  return new_handler->ha_open(identifier, getTable()->getDBStat(), HA_OPEN_IGNORE_IF_LOCKED) ? NULL : new_handler;
 }
 
 /*
@@ -246,13 +239,9 @@ int Cursor::ha_open(const identifier::Table &identifier,
     (void) extra(HA_EXTRA_NO_READCHECK);	// Not needed in SQL
 
     /* ref is already allocated for us if we're called from Cursor::clone() */
-    if (!ref && !(ref= (unsigned char*) getTable()->alloc_root(ALIGN_SIZE(ref_length)*2)))
-    {
-      close();
-      error=HA_ERR_OUT_OF_MEM;
-    }
-    else
-      dup_ref=ref+ALIGN_SIZE(ref_length);
+    if (!ref)
+      ref= getTable()->alloc(ALIGN_SIZE(ref_length)*2);
+    dup_ref=ref+ALIGN_SIZE(ref_length);
   }
   return error;
 }
@@ -476,22 +465,12 @@ int Cursor::update_auto_increment()
 
   if ((nr= next_insert_id) >= auto_inc_interval_for_cur_row.maximum())
   {
-    /* next_insert_id is beyond what is reserved, so we reserve more. */
-    const Discrete_interval *forced=
-      session->auto_inc_intervals_forced.get_next();
-    if (forced != NULL)
-    {
-      nr= forced->minimum();
-      nb_reserved_values= forced->values();
-    }
-    else
     {
       /*
         Cursor::estimation_rows_to_insert was set by
         Cursor::ha_start_bulk_insert(); if 0 it means "unknown".
       */
-      uint32_t nb_already_reserved_intervals=
-        session->auto_inc_intervals_in_cur_stmt_for_binlog.nb_elements();
+      uint32_t nb_already_reserved_intervals= 0;
       uint64_t nb_desired_values;
       /*
         If an estimation was given to the engine:
@@ -566,10 +545,7 @@ int Cursor::update_auto_increment()
       nr= getTable()->next_number_field->val_int();
   }
   if (append)
-  {
-    auto_inc_interval_for_cur_row.replace(nr, nb_reserved_values,
-                                          variables->auto_increment_increment);
-  }
+    auto_inc_interval_for_cur_row.replace(nr, nb_reserved_values, variables->auto_increment_increment);
 
   /*
     Record this autogenerated value. If the caller then
@@ -610,39 +586,15 @@ void Cursor::ha_release_auto_increment()
   release_auto_increment();
   insert_id_for_cur_row= 0;
   auto_inc_interval_for_cur_row.replace(0, 0, 0);
-  if (next_insert_id > 0)
-  {
-    next_insert_id= 0;
-    /*
-      this statement used forced auto_increment values if there were some,
-      wipe them away for other statements.
-    */
-    getTable()->in_use->auto_inc_intervals_forced.empty();
-  }
+  next_insert_id= 0;
 }
 
-void Cursor::drop_table(const char *)
+void Cursor::drop_table()
 {
   close();
 }
 
-
-/**
-  Performs checks upon the table.
-
-  @param session                thread doing CHECK Table operation
-  @param check_opt          options from the parser
-
-  @retval
-    HA_ADMIN_OK               Successful upgrade
-  @retval
-    HA_ADMIN_NEEDS_UPGRADE    Table has structures requiring upgrade
-  @retval
-    HA_ADMIN_NEEDS_ALTER      Table has structures requiring ALTER Table
-  @retval
-    HA_ADMIN_NOT_IMPLEMENTED
-*/
-int Cursor::ha_check(Session *, HA_CHECK_OPT *)
+int Cursor::ha_check(Session*)
 {
   return HA_ADMIN_OK;
 }
@@ -656,8 +608,6 @@ inline
 void
 Cursor::setTransactionReadWrite()
 {
-  ResourceContext *resource_context;
-
   /*
    * If the cursor has not context for execution then there should be no
    * possible resource to gain (and if there is... then there is a bug such
@@ -666,7 +616,6 @@ Cursor::setTransactionReadWrite()
   if (not getTable()->in_use)
     return;
 
-  resource_context= getTable()->in_use->getResourceContext(getEngine());
   /*
     When a storage engine method is called, the transaction must
     have been started, unless it's a DDL call, for which the
@@ -675,10 +624,9 @@ Cursor::setTransactionReadWrite()
     Unfortunately here we can't know know for sure if the engine
     has registered the transaction or not, so we must check.
   */
-  if (resource_context->isStarted())
-  {
-    resource_context->markModifiedData();
-  }
+  ResourceContext& resource_context= getTable()->in_use->getResourceContext(*getEngine());
+  if (resource_context.isStarted())
+    resource_context.markModifiedData();
 }
 
 
@@ -707,9 +655,8 @@ Cursor::ha_delete_all_rows()
      * @todo Make TransactionServices generic to AfterTriggerServices
      * or similar...
      */
-    Session *const session= getTable()->in_use;
-    TransactionServices &transaction_services= TransactionServices::singleton();
-    transaction_services.truncateTable(*session, *getTable());
+    Session& session= *getTable()->in_use;
+    TransactionServices::truncateTable(session, *getTable());
   }
 
   return result;
@@ -738,7 +685,7 @@ Cursor::ha_reset_auto_increment(uint64_t value)
 */
 
 int
-Cursor::ha_analyze(Session* session, HA_CHECK_OPT*)
+Cursor::ha_analyze(Session* session)
 {
   setTransactionReadWrite();
 
@@ -781,11 +728,9 @@ Cursor::ha_enable_indexes(uint32_t mode)
   @sa Cursor::discard_or_import_tablespace()
 */
 
-int
-Cursor::ha_discard_or_import_tablespace(bool discard)
+int Cursor::ha_discard_or_import_tablespace(bool discard)
 {
   setTransactionReadWrite();
-
   return discard_or_import_tablespace(discard);
 }
 
@@ -795,60 +740,58 @@ Cursor::ha_discard_or_import_tablespace(bool discard)
   @sa Cursor::drop_table()
 */
 
-void
-Cursor::closeMarkForDelete(const char *name)
+void Cursor::closeMarkForDelete()
 {
   setTransactionReadWrite();
-
-  return drop_table(name);
+  return drop_table();
 }
 
 int Cursor::index_next_same(unsigned char *buf, const unsigned char *key, uint32_t keylen)
 {
-  int error;
-  if (!(error=index_next(buf)))
+  int error= index_next(buf);
+  if (error)
+    return error;
+
+  ptrdiff_t ptrdiff= buf - getTable()->getInsertRecord();
+  unsigned char *save_record_0= NULL;
+  KeyInfo *key_info= NULL;
+  KeyPartInfo *key_part;
+  KeyPartInfo *key_part_end= NULL;
+
+  /*
+  key_cmp_if_same() compares table->getInsertRecord() against 'key'.
+  In parts it uses table->getInsertRecord() directly, in parts it uses
+  field objects with their local pointers into table->getInsertRecord().
+  If 'buf' is distinct from table->getInsertRecord(), we need to move
+  all record references. This is table->getInsertRecord() itself and
+  the field pointers of the fields used in this key.
+  */
+  if (ptrdiff)
   {
-    ptrdiff_t ptrdiff= buf - getTable()->getInsertRecord();
-    unsigned char *save_record_0= NULL;
-    KeyInfo *key_info= NULL;
-    KeyPartInfo *key_part;
-    KeyPartInfo *key_part_end= NULL;
-
-    /*
-      key_cmp_if_same() compares table->getInsertRecord() against 'key'.
-      In parts it uses table->getInsertRecord() directly, in parts it uses
-      field objects with their local pointers into table->getInsertRecord().
-      If 'buf' is distinct from table->getInsertRecord(), we need to move
-      all record references. This is table->getInsertRecord() itself and
-      the field pointers of the fields used in this key.
-    */
-    if (ptrdiff)
+    save_record_0= getTable()->getInsertRecord();
+    getTable()->record[0]= buf;
+    key_info= getTable()->key_info + active_index;
+    key_part= key_info->key_part;
+    key_part_end= key_part + key_info->key_parts;
+    for (; key_part < key_part_end; key_part++)
     {
-      save_record_0= getTable()->getInsertRecord();
-      getTable()->record[0]= buf;
-      key_info= getTable()->key_info + active_index;
-      key_part= key_info->key_part;
-      key_part_end= key_part + key_info->key_parts;
-      for (; key_part < key_part_end; key_part++)
-      {
-        assert(key_part->field);
-        key_part->field->move_field_offset(ptrdiff);
-      }
+      assert(key_part->field);
+      key_part->field->move_field_offset(ptrdiff);
     }
+  }
 
-    if (key_cmp_if_same(getTable(), key, active_index, keylen))
-    {
-      getTable()->status=STATUS_NOT_FOUND;
-      error=HA_ERR_END_OF_FILE;
-    }
+  if (key_cmp_if_same(getTable(), key, active_index, keylen))
+  {
+    getTable()->status=STATUS_NOT_FOUND;
+    error= HA_ERR_END_OF_FILE;
+  }
 
-    /* Move back if necessary. */
-    if (ptrdiff)
-    {
-      getTable()->record[0]= save_record_0;
-      for (key_part= key_info->key_part; key_part < key_part_end; key_part++)
-        key_part->field->move_field_offset(-ptrdiff);
-    }
+  /* Move back if necessary. */
+  if (ptrdiff)
+  {
+    getTable()->record[0]= save_record_0;
+    for (key_part= key_info->key_part; key_part < key_part_end; key_part++)
+      key_part->field->move_field_offset(-ptrdiff);
   }
   return error;
 }
@@ -1290,10 +1233,9 @@ static bool log_row_for_replication(Table* table,
                                     const unsigned char *before_record,
                                     const unsigned char *after_record)
 {
-  TransactionServices &transaction_services= TransactionServices::singleton();
   Session *const session= table->in_use;
 
-  if (table->getShare()->getType() || not transaction_services.shouldConstructMessages())
+  if (table->getShare()->getType() || not TransactionServices::shouldConstructMessages())
     return false;
 
   bool result= false;
@@ -1310,7 +1252,7 @@ static bool log_row_for_replication(Table* table,
      * CREATE TABLE will commit the transaction containing
      * it).
      */
-    result= transaction_services.insertRecord(*session, *table);
+    result= TransactionServices::insertRecord(*session, *table);
     break;
   case SQLCOM_REPLACE:
   case SQLCOM_REPLACE_SELECT:
@@ -1339,20 +1281,20 @@ static bool log_row_for_replication(Table* table,
        * as the row to delete (this is the conflicting row), so
        * we need to notify TransactionService to use that row.
        */
-      transaction_services.deleteRecord(*session, *table, true);
+      TransactionServices::deleteRecord(*session, *table, true);
       /* 
        * We set the "current" statement message to NULL.  This triggers
        * the replication services component to generate a new statement
        * message for the inserted record which will come next.
        */
-      transaction_services.finalizeStatementMessage(*session->getStatementMessage(), *session);
+      TransactionServices::finalizeStatementMessage(*session->getStatementMessage(), *session);
     }
     else
     {
       if (before_record == NULL)
-        result= transaction_services.insertRecord(*session, *table);
+        result= TransactionServices::insertRecord(*session, *table);
       else
-        transaction_services.updateRecord(*session, *table, before_record, after_record);
+        TransactionServices::updateRecord(*session, *table, before_record, after_record);
     }
     break;
   case SQLCOM_INSERT:
@@ -1365,17 +1307,17 @@ static bool log_row_for_replication(Table* table,
      * an update.
      */
     if (before_record == NULL)
-      result= transaction_services.insertRecord(*session, *table);
+      result= TransactionServices::insertRecord(*session, *table);
     else
-      transaction_services.updateRecord(*session, *table, before_record, after_record);
+      TransactionServices::updateRecord(*session, *table, before_record, after_record);
     break;
 
   case SQLCOM_UPDATE:
-    transaction_services.updateRecord(*session, *table, before_record, after_record);
+    TransactionServices::updateRecord(*session, *table, before_record, after_record);
     break;
 
   case SQLCOM_DELETE:
-    transaction_services.deleteRecord(*session, *table);
+    TransactionServices::deleteRecord(*session, *table);
     break;
   default:
     break;
