@@ -31,19 +31,9 @@
 #include <drizzled/util/find_ptr.h>
 
 #include <boost/unordered_map.hpp>
-#include <exception>
 
-namespace drizzled
-{
-namespace
-{
-
-class ErrorStringNotFound: public std::exception
-{
-public:
-  ErrorStringNotFound()
-  {}
-};
+namespace drizzled {
+namespace {
 
 ErrorMap& get_error_map()
 {
@@ -58,67 +48,60 @@ const ErrorMap::ErrorMessageMap& ErrorMap::get_error_message_map()
   return get_error_map().mapping_;
 }
 
-void add_error_message(drizzled::error_t error_code,
+void add_error_message(error_t error_code,
                        const std::string &error_name,
                        const std::string &message)
 {
   get_error_map().add(error_code, error_name, message);
 }
 
-const char * error_message(drizzled::error_t code)
+const char* error_message(error_t code)
 {
-  try
-  {
-    return get_error_map().find(code).c_str();
-  }
-  catch (ErrorStringNotFound const& e)
-  {
-    return get_error_map().find(ER_UNKNOWN_ERROR).c_str();
-  }
+	const std::string* ptr = get_error_map().find(code);
+	return ptr ? ptr->c_str() : get_error_map().find(ER_UNKNOWN_ERROR)->c_str();
 }
 
 error_handler_func error_handler_hook= NULL;
 
 namespace error {
 
-void access(drizzled::identifier::User::const_reference user)
+void access(const drizzled::identifier::User& user)
 {
-  std::string user_string;
-  user.getSQLPath(user_string);
-
-  my_error(ER_ACCESS_DENIED_ERROR, MYF(0), user_string.c_str(),
-           user.hasPassword() ? ER(ER_YES) : ER(ER_NO));
+  my_error(ER_ACCESS_DENIED_ERROR, MYF(0), user.getSQLPath().c_str(), ER(user.hasPassword() ? ER_YES : ER_NO));
 } 
 
-void access(drizzled::identifier::User::const_reference user, drizzled::identifier::Schema::const_reference schema)
+void access(const drizzled::identifier::User& user, const drizzled::identifier::Schema& schema)
 {
-  std::string user_string;
-  user.getSQLPath(user_string);
-
-  std::string schema_string;
-  schema.getSQLPath(schema_string);
-
-  my_error(ER_DBACCESS_DENIED_ERROR, MYF(0), user_string.c_str(), schema_string.c_str());
+  my_error(ER_DBACCESS_DENIED_ERROR, MYF(0), user.getSQLPath().c_str(), schema.getSQLPath().c_str());
 } 
 
-void access(drizzled::identifier::User::const_reference user, drizzled::identifier::Table::const_reference table)
+void access(const drizzled::identifier::User& user, const drizzled::identifier::Table& table)
 {
-  std::string user_string;
-  user.getSQLPath(user_string);
-
-  std::string table_string;
-  table.getSQLPath(table_string);
-
-  my_error(ER_TABLEACCESS_DENIED_ERROR, MYF(0), user_string.c_str(), table_string.c_str());
+  my_error(ER_TABLEACCESS_DENIED_ERROR, MYF(0), user.getSQLPath().c_str(), table.getSQLPath().c_str());
 } 
 
-static error::level_t _verbosity= error::ERROR;
+static error::priority_t _verbosity= error::ERROR;
 static std::string _verbosity_strint;
 
 const std::string &verbose_string()
 {
   switch (_verbosity)
   {
+  case error::ALERT:
+    {
+      static std::string _arg= "ALERT";
+      return _arg;
+    }
+  case error::EMERG:
+    {
+      static std::string _arg= "EMERG";
+      return _arg;
+    }
+  case error::CRITICAL:
+    {
+      static std::string _arg= "CRITICAL";
+      return _arg;
+    }
   case error::INSPECT:
     {
       static std::string _arg= "INSPECT";
@@ -135,16 +118,14 @@ const std::string &verbose_string()
       return _arg;
     }
   case error::ERROR:
-    {
-      static std::string _arg= "ERROR";
-      return _arg;
-    }
+    break;
   }
 
-  abort();
+  static std::string _arg= "ERROR";
+  return _arg;
 }
 
-error::level_t &verbosity()
+error::priority_t &verbosity()
 {
   return _verbosity;
 }
@@ -163,10 +144,20 @@ void check_verbosity(const std::string &arg)
   {
     _verbosity= error::WARN;
   }
-  else if (not arg.compare("ERROR"))
+  else if (not arg.compare("EMERG"))
   {
-    _verbosity= error::ERROR;
+    _verbosity= error::EMERG;
   }
+  else if (not arg.compare("CRITICAL"))
+  {
+    _verbosity= error::CRITICAL;
+  }
+  else if (not arg.compare("ALERT"))
+  {
+    _verbosity= error::ALERT;
+  }
+
+  _verbosity= error::ERROR;
 }
 
 } // namespace error
@@ -195,11 +186,9 @@ void my_error(const std::string &ref, error_t nr, myf MyFlags)
   my_error(nr, MyFlags, ref.c_str());
 } 
 
-void my_error(error_t nr, drizzled::Identifier::const_reference ref, myf MyFlags)
+void my_error(error_t nr, const drizzled::Identifier& id, myf MyFlags)
 {
-  std::string temp;
-  ref.getSQLPath(temp);
-  my_error(nr, MyFlags, temp.c_str());
+  my_error(nr, MyFlags, id.getSQLPath().c_str());
 } 
 
 void my_error(error_t nr)
@@ -209,21 +198,17 @@ void my_error(error_t nr)
 
 void my_error(error_t nr, myf MyFlags, ...)
 {
-  std::string format;
   va_list args;
   char ebuff[ERRMSGSIZE + 20];
 
-  try
-  {
-    format= get_error_map().find(nr);
+  if (const std::string* format= get_error_map().find(nr))
+	{	
     va_start(args,MyFlags);
-    (void) vsnprintf (ebuff, sizeof(ebuff), _(format.c_str()), args);
+    (void) vsnprintf (ebuff, sizeof(ebuff), _(format->c_str()), args);
     va_end(args);
   }
-  catch (ErrorStringNotFound const& e)
-  {
+	else
     (void) snprintf (ebuff, sizeof(ebuff), _("Unknown error %d"), nr);
-  }
   (*error_handler_hook)(nr, ebuff, MyFlags);
 }
 
@@ -282,14 +267,10 @@ void ErrorMap::add(drizzled::error_t error_num,
   }
 }
 
-const std::string &ErrorMap::find(drizzled::error_t error_num) const
+const std::string* ErrorMap::find(drizzled::error_t error_num) const
 {
   const ErrorMessageMap::mapped_type* pos= find_ptr(mapping_, error_num);
-  if (!pos)
-  {
-    throw ErrorStringNotFound();
-  }
-  return pos->second;
+	return pos ? &pos->second : NULL;
 }
 
 #define ADD_ERROR_MESSAGE(code, msg) add(code, STRINGIFY_ARG(code), msg)
@@ -640,6 +621,9 @@ ErrorMap::ErrorMap()
   ADD_ERROR_MESSAGE(ER_INVALID_UUID_VALUE, N_("Received an invalid UUID value"));
   ADD_ERROR_MESSAGE(ER_INVALID_UUID_TIME, N_("The UUID was not created with a valid time"));
 
+  // For IPV6 type
+  ADD_ERROR_MESSAGE(ER_INVALID_IPV6_VALUE, N_("Received an invalid IPV6 value"));
+
   // For BOOL type
   ADD_ERROR_MESSAGE(ER_INVALID_BOOLEAN_VALUE, N_("Received an invalid BOOLEAN value '%s'."));
   ADD_ERROR_MESSAGE(ER_INVALID_CAST_TO_BOOLEAN, N_("Invalid cast to BOOLEAN: '%s'."));
@@ -651,19 +635,19 @@ ErrorMap::ErrorMap()
   ADD_ERROR_MESSAGE(ER_ASSERT_NULL, N_("Assertion '%s' failed, the result was NULL."));
 
   // Some old error values use the same strings as some new error values.
-  ADD_ERROR_MESSAGE(EE_FILENOTFOUND, find(ER_FILE_NOT_FOUND));
-  ADD_ERROR_MESSAGE(EE_CANTCREATEFILE, find(ER_CANT_CREATE_FILE));
-  ADD_ERROR_MESSAGE(EE_READ, find(ER_ERROR_ON_READ));
-  ADD_ERROR_MESSAGE(EE_WRITE, find(ER_ERROR_ON_WRITE));
-  ADD_ERROR_MESSAGE(EE_BADCLOSE, find(ER_ERROR_ON_CLOSE));
-  ADD_ERROR_MESSAGE(EE_OUTOFMEMORY, find(ER_OUTOFMEMORY));
-  ADD_ERROR_MESSAGE(EE_DELETE, find(ER_CANT_DELETE_FILE));
-  ADD_ERROR_MESSAGE(EE_LINK, find(ER_ERROR_ON_RENAME));
-  ADD_ERROR_MESSAGE(EE_EOFERR, find(ER_UNEXPECTED_EOF));
-  ADD_ERROR_MESSAGE(EE_CANTLOCK, find(ER_CANT_LOCK));
-  ADD_ERROR_MESSAGE(EE_DIR, find(ER_CANT_READ_DIR));
-  ADD_ERROR_MESSAGE(EE_STAT, find(ER_CANT_GET_STAT));
-  ADD_ERROR_MESSAGE(EE_DISK_FULL, find(ER_DISK_FULL));
+  ADD_ERROR_MESSAGE(EE_FILENOTFOUND, *find(ER_FILE_NOT_FOUND));
+  ADD_ERROR_MESSAGE(EE_CANTCREATEFILE, *find(ER_CANT_CREATE_FILE));
+  ADD_ERROR_MESSAGE(EE_READ, *find(ER_ERROR_ON_READ));
+  ADD_ERROR_MESSAGE(EE_WRITE, *find(ER_ERROR_ON_WRITE));
+  ADD_ERROR_MESSAGE(EE_BADCLOSE, *find(ER_ERROR_ON_CLOSE));
+  ADD_ERROR_MESSAGE(EE_OUTOFMEMORY, *find(ER_OUTOFMEMORY));
+  ADD_ERROR_MESSAGE(EE_DELETE, *find(ER_CANT_DELETE_FILE));
+  ADD_ERROR_MESSAGE(EE_LINK, *find(ER_ERROR_ON_RENAME));
+  ADD_ERROR_MESSAGE(EE_EOFERR, *find(ER_UNEXPECTED_EOF));
+  ADD_ERROR_MESSAGE(EE_CANTLOCK, *find(ER_CANT_LOCK));
+  ADD_ERROR_MESSAGE(EE_DIR, *find(ER_CANT_READ_DIR));
+  ADD_ERROR_MESSAGE(EE_STAT, *find(ER_CANT_GET_STAT));
+  ADD_ERROR_MESSAGE(EE_DISK_FULL, *find(ER_DISK_FULL));
   
   // Catalog related errors
   ADD_ERROR_MESSAGE(ER_CATALOG_CANNOT_CREATE, N_("Cannot create catalog '%s'."));
@@ -678,6 +662,9 @@ ErrorMap::ErrorMap()
   ADD_ERROR_MESSAGE(ER_USE_DATA_DICTIONARY, N_("Engine status is now stored in the data_dictionary tables, please use these instead."));
   ADD_ERROR_MESSAGE(ER_TRANSACTION_ALREADY_STARTED, N_("There is already a transaction in progress"));
   ADD_ERROR_MESSAGE(ER_NO_LOCK_HELD, N_("No lock is held by this connection."));
+  
+  // Errors in scripts, such as JavaScript
+  ADD_ERROR_MESSAGE(ER_SCRIPT, N_("Script error: %s"));
 }
 
 } /* namespace drizzled */
