@@ -850,6 +850,7 @@ enum error_t {
   ER_INVALID_CAST_TO_UNSIGNED,
   ER_INVALID_UUID_TIME,
   ER_INVALID_UUID_VALUE,
+  ER_INVALID_IPV6_VALUE,
   ER_SQL_KEYWORD,
   ER_TABLE_DROP,
   ER_TABLE_DROP_ERROR_OCCURRED,
@@ -865,7 +866,8 @@ enum error_t {
   ER_USE_DATA_DICTIONARY,
   ER_TRANSACTION_ALREADY_STARTED,
   ER_CARTESIAN_JOIN_ATTEMPTED,
-  ER_NO_LOCK_HELD
+  ER_NO_LOCK_HELD,
+  ER_SCRIPT                                         /* Error executing script: (such as JavaScript) */
 };
 
 
