@@ -27,8 +27,7 @@
 #include <drizzled/time_functions.h>
 #include <drizzled/charset.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 bool Item_char_typecast::eq(const Item *item, bool binary_cmp) const
 {
@@ -98,14 +97,12 @@ String *Item_char_typecast::val_str(String *str)
   else
   {
     // Convert character set if differ
-    size_t dummy_errors;
-    if (!(res= args[0]->val_str(&tmp_value)) ||
-        str->copy(res->ptr(), res->length(), from_cs,
-        cast_cs, &dummy_errors))
+    if (!(res= args[0]->val_str(&tmp_value)))
     {
       null_value= 1;
       return 0;
     }
+		str->copy(res->ptr(), res->length(), cast_cs);
     res= str;
   }
 
@@ -133,7 +130,7 @@ String *Item_char_typecast::val_str(String *str)
       push_warning_printf(current_session, DRIZZLE_ERROR::WARN_LEVEL_WARN,
                           ER_TRUNCATED_WRONG_VALUE,
                           ER(ER_TRUNCATED_WRONG_VALUE), char_type,
-                          res->c_ptr_safe());
+                          res->c_str());
       res->length((uint) length);
     }
     else if (cast_cs == &my_charset_bin && res->length() < (uint) cast_length)
@@ -258,9 +255,9 @@ String *Item_date_typecast::val_str(String *str)
   assert(fixed == 1);
   type::Time ltime;
 
-  if (!get_arg0_date(ltime, TIME_FUZZY_DATE) &&
-      !str->alloc(type::Time::MAX_STRING_LENGTH))
+  if (!get_arg0_date(ltime, TIME_FUZZY_DATE))
   {
+    str->alloc(type::Time::MAX_STRING_LENGTH);
     ltime.convert(*str, type::DRIZZLE_TIMESTAMP_DATE);
 
     return str;
