@@ -19,15 +19,16 @@
  */
 
 #include <config.h>
-
-#include <assert.h>
-
+#include <cassert>
+#include <drizzled/errmsg_print.h>
+#include <drizzled/gettext.h>
 #include <drizzled/identifier.h>
 #include <drizzled/session.h>
 #include <drizzled/internal/my_sys.h>
 
 #include <drizzled/util/tablename_to_filename.h>
 #include <drizzled/util/backtrace.h>
+#include <drizzled/charset.h>
 
 #include <algorithm>
 #include <sstream>
@@ -37,52 +38,22 @@
 
 using namespace std;
 
-namespace drizzled
-{
+namespace drizzled {
+namespace identifier {
 
-namespace identifier
-{
-
-static void build_schema_filename(string &path, const string &name_arg)
-{
-  path.append("../");
-  bool conversion_error= false;
-
-  conversion_error= util::tablename_to_filename(name_arg, path);
-  if (conversion_error)
-  {
-    errmsg_printf(error::ERROR,
-                  _("Catalog name cannot be encoded and fit within filesystem "
-                    "name length restrictions."));
-  }
-}
-
-Catalog::Catalog(const std::string &name_arg) :
-  _name(name_arg)
+Catalog::Catalog(str_ref name_arg) :
+  _name(name_arg.data(), name_arg.size())
 { 
   init();
 }
 
-Catalog::Catalog(const drizzled::LEX_STRING &name_arg) :
-  _name(name_arg.str, name_arg.length)
-{
-  init();
-}
-
-void  Catalog::init()
+void Catalog::init()
 { 
   assert(not _name.empty());
-
-  build_schema_filename(path, _name);
+  path += "../";
+  path += util::tablename_to_filename(_name);
   assert(path.length()); // TODO throw exception, this is a possibility
-
-  util::insensitive_hash hasher;
-  hash_value= hasher(path);
-}
-
-const std::string &Catalog::getPath() const
-{
-  return path;
+  hash_value= util::insensitive_hash()(path);
 }
 
 bool Catalog::compare(const std::string &arg) const
@@ -92,44 +63,22 @@ bool Catalog::compare(const std::string &arg) const
 
 bool Catalog::isValid() const
 {
-  if (_name.empty())
+  if (_name.empty()
+    || _name.size() > NAME_LEN
+    || _name.at(_name.length() -1 ) == ' ')
     return false;
-
-  if (_name.size() > NAME_LEN)
-    return false;
-
-  if (_name.at(_name.length() -1) == ' ')
-    return false;
-
-  const CHARSET_INFO * const cs= &my_charset_utf8mb4_general_ci;
-
+  const charset_info_st& cs= my_charset_utf8mb4_general_ci;
   int well_formed_error;
-  uint32_t res= cs->cset->well_formed_len(cs, _name.c_str(), _name.c_str() + _name.length(),
-                                          NAME_CHAR_LEN, &well_formed_error);
-
+  uint32_t res= cs.cset->well_formed_len(cs, _name, NAME_CHAR_LEN, &well_formed_error);
   if (well_formed_error)
   {
     my_error(ER_INVALID_CHARACTER_STRING, MYF(0), "identifier", _name.c_str());
     return false;
   }
-
   if (_name.length() != res)
     return false;
-
   return true;
 }
 
-std::size_t hash_value(Catalog const& b)
-{
-  return b.getHashValue();
-}
-
-void Catalog::getSQLPath(std::string &sql_path) const
-{
-  sql_path= _name;
-}
-
-
-
 } /* namespace identifier */
 } /* namespace drizzled */
