@@ -54,6 +54,7 @@
 #include <drizzled/item/ref.h>
 #include <drizzled/item/subselect.h>
 #include <drizzled/sql_lex.h>
+#include <drizzled/system_variables.h>
 
 #include <cstdio>
 #include <math.h>
@@ -62,8 +63,7 @@
 
 using namespace std;
 
-namespace drizzled
-{
+namespace drizzled {
 
 const String my_null_string("NULL", 4, default_charset_info);
 
@@ -175,11 +175,9 @@ type::Decimal *Item::val_decimal_from_int(type::Decimal *decimal_value)
 type::Decimal *Item::val_decimal_from_string(type::Decimal *decimal_value)
 {
   String *res;
-  char *end_ptr;
   if (!(res= val_str(&str_value)))
     return NULL;
 
-  end_ptr= (char*) res->ptr()+ res->length();
   if (decimal_value->store(E_DEC_FATAL_ERROR & ~E_DEC_BAD_NUM,
                      res->ptr(), 
                      res->length(), 
@@ -285,7 +283,6 @@ Item::Item():
   is_expensive_cache(-1),
   name(0), 
   name_length(0),
-  orig_name(0), 
   max_length(0), 
   marker(0),
   decimals(0),
@@ -323,7 +320,6 @@ Item::Item(Session *session, Item *item):
   str_value(item->str_value),
   name(item->name),
   name_length(item->name_length),
-  orig_name(item->orig_name),
   max_length(item->max_length),
   marker(item->marker),
   decimals(item->decimals),
@@ -375,7 +371,7 @@ void Item::print_item_w_name(String *str)
   if (name)
   {
     str->append(STRING_WITH_LEN(" AS "));
-    str->append_identifier(name, (uint32_t) strlen(name));
+    str->append_identifier(str_ref(name));
   }
 }
 
@@ -386,20 +382,6 @@ void Item::cleanup()
 {
   fixed= false;
   marker= 0;
-  if (orig_name)
-    name= orig_name;
-  return;
-}
-
-void Item::rename(char *new_name)
-{
-  /*
-    we can compare pointers to names here, because if name was not changed,
-    pointer will be same
-  */
-  if (! orig_name && new_name != name)
-    orig_name= name;
-  name= new_name;
 }
 
 Item* Item::transform(Item_transformer transformer, unsigned char *arg)
@@ -417,41 +399,35 @@ bool Item::check_cols(uint32_t c)
   return false;
 }
 
-void Item::set_name(const char *str, uint32_t length, const CHARSET_INFO * const cs)
+void Item::set_name(const char *str, uint32_t length, const charset_info_st* cs)
 {
-  if (!length)
+  if (not length)
   {
+    if (0) // str && *str)
+      std::cerr << "non-empty empty name: " << str << std::endl;
     /* Empty string, used by AS or internal function like last_insert_id() */
-    name= (char*) str;
+    name= str; // should be NULL (or "");
     name_length= 0;
     return;
   }
   if (cs->ctype)
   {
     uint32_t orig_len= length;
-    while (length && ! my_isgraph(cs, *str))
+    while (length && not cs->isgraph(*str))
     {
       /* Fix problem with yacc */
       length--;
       str++;
     }
-    if (orig_len != length && ! is_autogenerated_name)
+    if (orig_len != length && not is_autogenerated_name)
     {
       if (length == 0)
-        push_warning_printf(&getSession(), 
-                            DRIZZLE_ERROR::WARN_LEVEL_WARN,
-                            ER_NAME_BECOMES_EMPTY, 
-                            ER(ER_NAME_BECOMES_EMPTY),
-                            str + length - orig_len);
+        push_warning_printf(&getSession(), DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_NAME_BECOMES_EMPTY, ER(ER_NAME_BECOMES_EMPTY), str + length - orig_len);
       else
-        push_warning_printf(&getSession(),
-                            DRIZZLE_ERROR::WARN_LEVEL_WARN,
-                            ER_REMOVED_SPACES, 
-                            ER(ER_REMOVED_SPACES),
-                            str + length - orig_len);
+        push_warning_printf(&getSession(), DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_REMOVED_SPACES, ER(ER_REMOVED_SPACES), str + length - orig_len);
     }
   }
-  name= memory::sql_strmake(str, length);
+  name= memory::sql_strdup(str_ref(str, length));
 }
 
 bool Item::eq(const Item *item, bool) const
@@ -464,13 +440,13 @@ bool Item::eq(const Item *item, bool) const
   return type() == item->type() && 
          name && 
          item->name &&
-         ! my_strcasecmp(system_charset_info, name, item->name);
+         not system_charset_info->strcasecmp(name, item->name);
 }
 
-Item *Item::safe_charset_converter(const CHARSET_INFO * const tocs)
+Item *Item::safe_charset_converter(const charset_info_st* tocs)
 {
   Item_func_conv_charset *conv= new Item_func_conv_charset(this, tocs, 1);
-  return conv->safe ? conv : NULL;
+  return conv->safe ? conv : NULL; // memory leak? (conv if not conv->safe)
 }
 
 bool Item::get_date(type::Time &ltime,uint32_t fuzzydate)
@@ -484,10 +460,9 @@ bool Item::get_date(type::Time &ltime,uint32_t fuzzydate)
     else if (result_type() == STRING_RESULT)
     {
       char buff[type::Time::MAX_STRING_LENGTH];
-      String tmp(buff,sizeof(buff), &my_charset_bin),*res;
-      if (!(res=val_str(&tmp)) ||
-          str_to_datetime_with_warn(&getSession(), res->ptr(), res->length(),
-                                    &ltime, fuzzydate) <= type::DRIZZLE_TIMESTAMP_ERROR)
+      String tmp(buff,sizeof(buff), &my_charset_bin);
+      String *res= val_str(&tmp);
+      if (not res || str_to_datetime_with_warn(getSession(), *res, ltime, fuzzydate) <= type::DRIZZLE_TIMESTAMP_ERROR)
       {
         break;
       }
@@ -501,10 +476,9 @@ bool Item::get_date(type::Time &ltime,uint32_t fuzzydate)
 
       if (not type::is_valid(date_value))
       {
-        char buff[DECIMAL_LONGLONG_DIGITS], *end;
-        end= internal::int64_t10_to_str(value, buff, -10);
-        make_truncated_value_warning(&getSession(), DRIZZLE_ERROR::WARN_LEVEL_WARN,
-                                     buff, (int) (end-buff), type::DRIZZLE_TIMESTAMP_NONE, NULL);
+        char buff[DECIMAL_LONGLONG_DIGITS];
+        char* end= internal::int64_t10_to_str(value, buff, -10);
+        make_truncated_value_warning(getSession(), DRIZZLE_ERROR::WARN_LEVEL_WARN, str_ref(buff, (int) (end-buff)), type::DRIZZLE_TIMESTAMP_NONE, NULL);
         break;
       }
     }
@@ -520,12 +494,11 @@ bool Item::get_date(type::Time &ltime,uint32_t fuzzydate)
 bool Item::get_time(type::Time &ltime)
 {
   char buff[type::Time::MAX_STRING_LENGTH];
-  String tmp(buff,sizeof(buff),&my_charset_bin),*res;
-  if (!(res=val_str(&tmp)) or
-      str_to_time_with_warn(&getSession(), res->ptr(), res->length(), &ltime))
+  String tmp(buff,sizeof(buff),&my_charset_bin);
+  String *res= val_str(&tmp);
+  if (not res || str_to_time_with_warn(getSession(), *res, ltime))
   {
     ltime.reset();
-
     return true;
   }
 
@@ -594,12 +567,12 @@ Item *Item::get_tmp_table_item(Session *session)
   return copy_or_same(session);
 }
 
-const CHARSET_INFO *Item::default_charset()
+const charset_info_st *Item::default_charset()
 {
   return current_session->variables.getCollation();
 }
 
-const CHARSET_INFO *Item::compare_collation()
+const charset_info_st *Item::compare_collation()
 {
   return NULL;
 }
@@ -609,14 +582,11 @@ bool Item::walk(Item_processor processor, bool, unsigned char *arg)
   return (this->*processor)(arg);
 }
 
-Item* Item::compile(Item_analyzer analyzer, 
-                    unsigned char **arg_p,
-                    Item_transformer transformer, 
-                    unsigned char *arg_t)
+Item* Item::compile(Item_analyzer analyzer, unsigned char **arg_p, Item_transformer transformer, unsigned char *arg_t)
 {
-  if ((this->*analyzer) (arg_p))
-    return ((this->*transformer) (arg_t));
-  return NULL;
+  return (this->*analyzer)(arg_p)
+    ? (this->*transformer)(arg_t)
+    : NULL;
 }
 
 void Item::traverse_cond(Cond_traverser traverser, void *arg, traverse_order)
@@ -629,12 +599,6 @@ bool Item::remove_dependence_processor(unsigned char *)
   return false;
 }
 
-bool Item::remove_fixed(unsigned char *)
-{
-  fixed= false;
-  return false;
-}
-
 bool Item::collect_item_field_processor(unsigned char *)
 {
   return false;
@@ -724,8 +688,7 @@ bool Item::result_as_int64_t()
 bool Item::is_expensive()
 {
   if (is_expensive_cache < 0)
-    is_expensive_cache= walk(&Item::is_expensive_processor, 0,
-                             (unsigned char*)0);
+    is_expensive_cache= walk(&Item::is_expensive_processor, 0, NULL);
   return test(is_expensive_cache);
 }
 
@@ -787,9 +750,7 @@ void Item::split_sum_func(Session *session, Item **ref_pointer_array,
     Item *real_itm= real_item();
 
     ref_pointer_array[el]= real_itm;
-    if (!(item_ref= new Item_aggregate_ref(&session->lex().current_select->context,
-                                           ref_pointer_array + el, 0, name)))
-      return; /* fatal_error is set */
+    item_ref= new Item_aggregate_ref(&session->lex().current_select->context, ref_pointer_array + el, 0, name);
     if (type() == SUM_FUNC_ITEM)
       item_ref->depended_from= ((Item_sum *) this)->depended_from();
     fields.push_front(real_itm);
@@ -911,7 +872,7 @@ static Item** find_field_in_group_list(Session *session, Item *find_item, Order
   {
     /* Convert database to lower case for comparison */
     strncpy(name_buff, db_name, sizeof(name_buff)-1);
-    my_casedn_str(files_charset_info, name_buff);
+    files_charset_info->casedn_str(name_buff);
     db_name= name_buff;
   }
 
@@ -926,15 +887,14 @@ static Item** find_field_in_group_list(Session *session, Item *find_item, Order
 
       assert(cur_field->field_name != 0);
 
-      if (! my_strcasecmp(system_charset_info, cur_field->field_name, field_name))
-        ++cur_match_degree;
-      else
+      if (system_charset_info->strcasecmp(cur_field->field_name, field_name))
         continue;
+      ++cur_match_degree;
 
       if (cur_field->table_name && table_name)
       {
         /* If field_name is qualified by a table name. */
-        if (my_strcasecmp(table_alias_charset, cur_field->table_name, table_name))
+        if (table_alias_charset->strcasecmp(cur_field->table_name, table_name))
           /* Same field names, different tables. */
           return NULL;
 
@@ -942,7 +902,7 @@ static Item** find_field_in_group_list(Session *session, Item *find_item, Order
         if (cur_field->db_name && db_name)
         {
           /* If field_name is also qualified by a database name. */
-          if (my_strcasecmp(system_charset_info, cur_field->db_name, db_name))
+          if (system_charset_info->strcasecmp(cur_field->db_name, db_name))
           {
             /* Same field names, different databases. */
             return NULL;
@@ -1038,19 +998,15 @@ Item** resolve_ref_in_select_and_group(Session *session, Item_ident *ref, Select
   return (Item**) not_found_item;
 }
 
-void Item::init_make_field(SendField *tmp_field,
-                           enum enum_field_types field_type_arg)
+void Item::init_make_field(SendField *tmp_field, enum_field_types field_type_arg)
 {
-  char *empty_name= (char*) "";
-  tmp_field->db_name=	empty_name;
-  tmp_field->org_table_name= empty_name;
-  tmp_field->org_col_name= empty_name;
-  tmp_field->table_name= empty_name;
+  tmp_field->db_name=	"";
+  tmp_field->org_table_name= "";
+  tmp_field->org_col_name= "";
+  tmp_field->table_name= "";
   tmp_field->col_name= name;
   tmp_field->charsetnr= collation.collation->number;
-  tmp_field->flags= (maybe_null ? 0 : NOT_NULL_FLAG) |
-                    (my_binary_compare(collation.collation) ?
-                      BINARY_FLAG : 0);
+  tmp_field->flags= (maybe_null ? 0 : NOT_NULL_FLAG) | (collation.collation->binary_compare() ? BINARY_FLAG : 0);
   tmp_field->type= field_type_arg;
   tmp_field->length= max_length;
   tmp_field->decimals= decimals;
@@ -1095,11 +1051,9 @@ bool Item::is_datetime()
 String *Item::check_well_formed_result(String *str, bool send_error)
 {
   /* Check whether we got a well-formed string */
-  const CHARSET_INFO * const cs= str->charset();
+  const charset_info_st * const cs= str->charset();
   int well_formed_error;
-  uint32_t wlen= cs->cset->well_formed_len(cs,
-                                       str->ptr(), str->ptr() + str->length(),
-                                       str->length(), &well_formed_error);
+  uint32_t wlen= cs->cset->well_formed_len(*cs, *str, str->length(), &well_formed_error);
   if (wlen < str->length())
   {
     char hexbuf[7];
@@ -1124,10 +1078,10 @@ String *Item::check_well_formed_result(String *str, bool send_error)
   return str;
 }
 
-bool Item::eq_by_collation(Item *item, bool binary_cmp, const CHARSET_INFO * const cs)
+bool Item::eq_by_collation(Item *item, bool binary_cmp, const charset_info_st * const cs)
 {
-  const CHARSET_INFO *save_cs= 0;
-  const CHARSET_INFO *save_item_cs= 0;
+  const charset_info_st *save_cs= 0;
+  const charset_info_st *save_item_cs= 0;
   if (collation.collation != cs)
   {
     save_cs= collation.collation;
@@ -1217,6 +1171,7 @@ Field *Item::tmp_table_field_from_field_type(Table *table, bool)
     break;
   case DRIZZLE_TYPE_BOOLEAN:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_IPV6:
   case DRIZZLE_TYPE_ENUM:
   case DRIZZLE_TYPE_VARCHAR:
     return make_string_field(table);
@@ -1242,7 +1197,7 @@ int Item::save_in_field(Field *field, bool no_conversions)
   if (result_type() == STRING_RESULT)
   {
     String *result;
-    const CHARSET_INFO * const cs= collation.collation;
+    const charset_info_st * const cs= collation.collation;
     char buff[MAX_FIELD_WIDTH];		// Alloc buffer for small columns
     str_value.set_quick(buff, sizeof(buff), cs);
     result=val_str(&str_value);
@@ -1354,12 +1309,10 @@ Item* Item::cache_const_expr_transformer(unsigned char *arg)
   return this;
 }
 
-bool Item::send(plugin::Client *client, String *buffer)
+void Item::send(plugin::Client *client, String *buffer)
 {
-  bool result= false;
-  enum_field_types f_type;
-
-  switch ((f_type=field_type())) {
+  switch (field_type())
+  {
   case DRIZZLE_TYPE_DATE:
   case DRIZZLE_TYPE_NULL:
   case DRIZZLE_TYPE_ENUM:
@@ -1367,31 +1320,29 @@ bool Item::send(plugin::Client *client, String *buffer)
   case DRIZZLE_TYPE_VARCHAR:
   case DRIZZLE_TYPE_BOOLEAN:
   case DRIZZLE_TYPE_UUID:
+  case DRIZZLE_TYPE_IPV6:
   case DRIZZLE_TYPE_DECIMAL:
     {
-      String *res;
-      if ((res=val_str(buffer)))
-        result= client->store(res->ptr(),res->length());
+      if (String* res=val_str(buffer))
+        client->store(res->ptr(), res->length());
       break;
     }
   case DRIZZLE_TYPE_LONG:
     {
-      int64_t nr;
-      nr= val_int();
+      int64_t nr= val_int();
       if (!null_value)
-        result= client->store((int32_t)nr);
+        client->store((int32_t)nr);
       break;
     }
   case DRIZZLE_TYPE_LONGLONG:
     {
-      int64_t nr;
-      nr= val_int();
+      int64_t nr= val_int();
       if (!null_value)
       {
         if (unsigned_flag)
-          result= client->store((uint64_t)nr);
+          client->store((uint64_t)nr);
         else
-          result= client->store((int64_t)nr);
+          client->store((int64_t)nr);
       }
       break;
     }
@@ -1399,7 +1350,7 @@ bool Item::send(plugin::Client *client, String *buffer)
     {
       double nr= val_real();
       if (!null_value)
-        result= client->store(nr, decimals, buffer);
+        client->store(nr, decimals, buffer);
       break;
     }
   case DRIZZLE_TYPE_TIME:
@@ -1407,7 +1358,7 @@ bool Item::send(plugin::Client *client, String *buffer)
       type::Time tm;
       get_time(tm);
       if (not null_value)
-        result= client->store(&tm);
+        client->store(&tm);
       break;
     }
   case DRIZZLE_TYPE_DATETIME:
@@ -1417,14 +1368,12 @@ bool Item::send(plugin::Client *client, String *buffer)
       type::Time tm;
       get_date(tm, TIME_FUZZY_DATE);
       if (!null_value)
-        result= client->store(&tm);
+        client->store(&tm);
       break;
     }
   }
   if (null_value)
-    result= client->store();
-
-  return result;
+    client->store();
 }
 
 uint32_t Item::max_char_length() const
@@ -1432,39 +1381,11 @@ uint32_t Item::max_char_length() const
   return max_length / collation.collation->mbmaxlen;
 }
 
-void Item::fix_length_and_charset(uint32_t max_char_length_arg, CHARSET_INFO *cs)
-{ 
-  max_length= char_to_byte_length_safe(max_char_length_arg, cs->mbmaxlen);
-  collation.collation= cs;
-}
-
 void Item::fix_char_length(uint32_t max_char_length_arg)
 { 
   max_length= char_to_byte_length_safe(max_char_length_arg, collation.collation->mbmaxlen);
 }
 
-void Item::fix_char_length_uint64_t(uint64_t max_char_length_arg)
-{ 
-  uint64_t max_result_length= max_char_length_arg *
-    collation.collation->mbmaxlen;
-
-  if (max_result_length >= MAX_BLOB_WIDTH)
-  { 
-    max_length= MAX_BLOB_WIDTH;
-    maybe_null= false;
-  }
-  else
-  {
-    max_length= max_result_length;
-  }
-}
-
-void Item::fix_length_and_charset_datetime(uint32_t max_char_length_arg)
-{ 
-  collation.set(&my_charset_bin);
-  fix_char_length(max_char_length_arg);
-}
-
 Item_result item_cmp_type(Item_result a,Item_result b)
 {
   if (a == STRING_RESULT && b == STRING_RESULT)
@@ -1488,11 +1409,11 @@ void resolve_const_item(Session *session, Item **ref, Item *comp_item)
   Item *new_item= NULL;
   if (item->basic_const_item())
     return; /* Can't be better */
-  Item_result res_type=item_cmp_type(comp_item->result_type(),
-				     item->result_type());
-  char *name=item->name; /* Alloced by memory::sql_alloc */
+  Item_result res_type=item_cmp_type(comp_item->result_type(), item->result_type());
+  const char *name=item->name; /* Alloced by memory::sql_alloc */
 
-  switch (res_type) {
+  switch (res_type) 
+  {
   case STRING_RESULT:
     {
       char buff[MAX_FIELD_WIDTH];
@@ -1501,20 +1422,12 @@ void resolve_const_item(Session *session, Item **ref, Item *comp_item)
       if (item->null_value)
         new_item= new Item_null(name);
       else
-      {
-        uint32_t length= result->length();
-        char *tmp_str= memory::sql_strmake(result->ptr(), length);
-        new_item= new Item_string(name, tmp_str, length, result->charset());
-      }
+        new_item= new Item_string(name, memory::sql_strdup(*result), result->length(), result->charset());
       break;
     }
   case INT_RESULT:
     {
-      int64_t result=item->val_int();
-      uint32_t length=item->max_length;
-      bool null_value=item->null_value;
-      new_item= (null_value ? (Item*) new Item_null(name) :
-                 (Item*) new Item_int(name, result, length));
+      new_item= item->null_value ? (Item*)new Item_null(name) : (Item*)new Item_int(name, item->val_int(), item->max_length);
       break;
     }
   case ROW_RESULT:
@@ -1530,7 +1443,6 @@ void resolve_const_item(Session *session, Item **ref, Item *comp_item)
       */
       Item_row *item_row= (Item_row*) item;
       Item_row *comp_item_row= (Item_row*) comp_item;
-      uint32_t col;
       new_item= 0;
       /*
         If item and comp_item are both Item_rows and have same number of cols
@@ -1540,10 +1452,8 @@ void resolve_const_item(Session *session, Item **ref, Item *comp_item)
       */
       assert(item->result_type() == comp_item->result_type());
       assert(item_row->cols() == comp_item_row->cols());
-      col= item_row->cols();
-      while (col-- > 0)
-        resolve_const_item(session, item_row->addr(col),
-                           comp_item_row->element_index(col));
+      for (uint32_t col= item_row->cols(); col--; )
+        resolve_const_item(session, item_row->addr(col), comp_item_row->element_index(col));
       break;
     }
     /* Fallthrough */
@@ -1612,9 +1522,6 @@ bool field_is_equal_to_item(Field *field,Item *item)
   return result == field->val_real();
 }
 
-void dummy_error_processor(Session *, void *)
-{}
-
 /**
   Create field for temporary table using type of given item.
 
@@ -1661,18 +1568,15 @@ static Field *create_tmp_field_from_item(Session *,
     */
     if (item->unsigned_flag)
     {
-      new_field= new field::Size(item->max_length, maybe_null,
-                                  item->name, item->unsigned_flag);
+      new_field= new field::Size(item->max_length, maybe_null, item->name, item->unsigned_flag);
     }
-    else if (item->max_length >= (MY_INT32_NUM_DECIMAL_DIGITS - 1))
+    else if (item->max_length >= MY_INT32_NUM_DECIMAL_DIGITS - 1)
     {
-      new_field= new field::Int64(item->max_length, maybe_null,
-                                  item->name, item->unsigned_flag);
+      new_field= new field::Int64(item->max_length, maybe_null, item->name, item->unsigned_flag);
     }
     else
     {
-      new_field= new field::Int32(item->max_length, maybe_null,
-                                  item->name, item->unsigned_flag);
+      new_field= new field::Int32(item->max_length, maybe_null, item->name, item->unsigned_flag);
     }
 
     break;
