@@ -34,8 +34,7 @@
 
 #include <boost/dynamic_bitset.hpp>
 
-namespace drizzled
-{
+namespace drizzled {
 
 /**
   Store the pointer to this item field into a list if not already there.
@@ -59,14 +58,13 @@ bool Item_field::collect_item_field_processor(unsigned char *arg)
 {
   List<Item_field> *item_list= (List<Item_field>*) arg;
   List<Item_field>::iterator item_list_it(item_list->begin());
-  Item_field *curr_item;
-  while ((curr_item= item_list_it++))
+  while (Item_field* curr_item= item_list_it++)
   {
     if (curr_item->eq(this, 1))
-      return(false); /* Already in the set. */
+      return false; /* Already in the set. */
   }
   item_list->push_back(this);
-  return(false);
+  return false;
 }
 
 
@@ -90,9 +88,8 @@ bool Item_field::find_item_in_field_list_processor(unsigned char *arg)
 {
   KeyPartInfo *first_non_group_part= *((KeyPartInfo **) arg);
   KeyPartInfo *last_part= *(((KeyPartInfo **) arg) + 1);
-  KeyPartInfo *cur_part;
 
-  for (cur_part= first_non_group_part; cur_part != last_part; cur_part++)
+  for (KeyPartInfo* cur_part= first_non_group_part; cur_part != last_part; cur_part++)
   {
     if (field->eq(cur_part->field))
       return true;
@@ -216,7 +213,7 @@ void Item_field::reset_field(Field *f)
 {
   set_field(f);
   /* 'name' is pointing at field->field_name of old field */
-  name= (char*) f->field_name;
+  name= f->field_name;
 }
 
 /* ARGSUSED */
@@ -325,7 +322,8 @@ bool Item_field::val_bool_result()
     return false;
   }
 
-  switch (result_field->result_type()) {
+  switch (result_field->result_type()) 
+  {
   case INT_RESULT:
     return result_field->val_int() != 0;
 
@@ -343,12 +341,12 @@ bool Item_field::val_bool_result()
     return result_field->val_real() != 0.0;
 
   case ROW_RESULT:
-    assert(0);
-    return 0;                                   // Shut up compiler
+    assert(false);
+    return 0;
   }
 
-  assert(0);
-  return 0;                                   // Shut up compiler
+  assert(false);
+  return 0;
 }
 
 
@@ -371,11 +369,11 @@ bool Item_field::eq(const Item *item, bool) const
     (In cases where we would choose wrong we would have to generate a
     ER_NON_UNIQ_ERROR).
   */
-  return (not my_strcasecmp(system_charset_info, item_field->name, field_name) &&
+  return (not system_charset_info->strcasecmp(item_field->name, field_name) &&
           (not item_field->table_name || not table_name ||
-           (not my_strcasecmp(table_alias_charset, item_field->table_name, table_name) &&
+           (not table_alias_charset->strcasecmp(item_field->table_name, table_name) &&
             (not item_field->db_name || not db_name ||
-             (item_field->db_name && not my_strcasecmp(system_charset_info, item_field->db_name, db_name))))));
+             (item_field->db_name && not system_charset_info->strcasecmp(item_field->db_name, db_name))))));
 }
 
 
@@ -386,7 +384,7 @@ table_map Item_field::used_tables() const
     return 0;					// const item
   }
 
-  return (depended_from ? OUTER_REF_TABLE_BIT : field->getTable()->map);
+  return depended_from ? OUTER_REF_TABLE_BIT : field->getTable()->map;
 }
 
 enum Item_result Item_field::result_type () const
@@ -429,8 +427,7 @@ bool Item_field::is_null()
 Item *Item_field::get_tmp_table_item(Session *session)
 {
   Item_field *new_item= new Item_field(session, this);
-  if (new_item)
-    new_item->field= new_item->result_field;
+  new_item->field= new_item->result_field;
   return new_item;
 }
 
@@ -549,7 +546,6 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
               select->group_list.elements &&
               (place == SELECT_LIST || place == IN_HAVING))
           {
-            Item_outer_ref *rf;
             /*
               If an outer field is resolved in a grouping select then it
               is replaced for an Item_outer_ref object. Otherwise an
@@ -559,9 +555,7 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
               after the original field has been fixed and this is done in the
               fix_inner_refs() function.
             */
-            ;
-            if (!(rf= new Item_outer_ref(context, this)))
-              return -1;
+            Item_outer_ref* rf= new Item_outer_ref(context, this);
             *reference= rf;
             select->inner_refs_list.push_back(rf);
             rf->in_sum_func= session->lex().in_sum_func;
@@ -590,15 +584,10 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
         else
         {
           Item::Type ref_type= (*reference)->type();
-          prev_subselect_item->used_tables_cache|=
-            (*reference)->used_tables();
-          prev_subselect_item->const_item_cache&=
-            (*reference)->const_item();
+          prev_subselect_item->used_tables_cache|= (*reference)->used_tables();
+          prev_subselect_item->const_item_cache&= (*reference)->const_item();
           mark_as_dependent(session, last_checked_context->select_lex,
-                            context->select_lex, this,
-                            ((ref_type == REF_ITEM || ref_type == FIELD_ITEM) ?
-                             (Item_ident*) (*reference) :
-                             0));
+            context->select_lex, this, ((ref_type == REF_ITEM || ref_type == FIELD_ITEM) ? (Item_ident*) (*reference) : 0));
           /*
             A reference to a view field had been found and we
             substituted it instead of this Item (find_field_in_tables
@@ -656,9 +645,6 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
   }
   else if (ref != not_found_item)
   {
-    Item *save;
-    Item_ref *rf;
-
     /* Should have been checked in resolve_ref_in_select_and_group(). */
     assert(*ref && (*ref)->fixed);
     /*
@@ -667,16 +653,13 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
       constructor, so no initialization is performed, and call
       fix_fields() below.
     */
-    save= *ref;
+    Item* save= *ref;
     *ref= NULL;                             // Don't call set_properties()
-    rf= (place == IN_HAVING ?
-         new Item_ref(context, ref, (char*) table_name,
-                      (char*) field_name, alias_name_used) :
+    Item_ref* rf= (place == IN_HAVING ?
+         new Item_ref(context, ref, table_name, field_name, alias_name_used) :
          (!select->group_list.elements ?
-         new Item_direct_ref(context, ref, (char*) table_name,
-                             (char*) field_name, alias_name_used) :
-         new Item_outer_ref(context, ref, (char*) table_name,
-                            (char*) field_name, alias_name_used)));
+         new Item_direct_ref(context, ref, table_name, field_name, alias_name_used) :
+         new Item_outer_ref(context, ref, table_name, field_name, alias_name_used)));
     *ref= save;
     if (!rf)
       return -1;
@@ -695,24 +678,15 @@ Item_field::fix_outer_field(Session *session, Field **from_field, Item **referen
     if (rf->fix_fields(session, reference) || rf->check_cols(1))
       return -1;
 
-    mark_as_dependent(session, last_checked_context->select_lex,
-                      context->select_lex, this,
-                      rf);
+    mark_as_dependent(session, last_checked_context->select_lex, context->select_lex, this, rf);
     return 0;
   }
   else
   {
-    mark_as_dependent(session, last_checked_context->select_lex,
-                      context->select_lex,
-                      this, (Item_ident*)*reference);
+    mark_as_dependent(session, last_checked_context->select_lex, context->select_lex, this, (Item_ident*)*reference);
     if (last_checked_context->select_lex->having_fix_field)
     {
-      Item_ref *rf;
-      rf= new Item_ref(context,
-                       (cached_table->getSchemaName()[0] ? cached_table->getSchemaName() : 0),
-                       (char*) cached_table->alias, (char*) field_name);
-      if (!rf)
-        return -1;
+      Item_ref* rf= new Item_ref(context, (cached_table->getSchemaName()[0] ? cached_table->getSchemaName() : 0), cached_table->alias, field_name);
       *reference= rf;
       /*
         rf is Item_ref => never substitute other items (in this case)
@@ -827,7 +801,7 @@ bool Item_field::fix_fields(Session *session, Item **reference)
               /* The column to which we link isn't valid. */
               my_error(ER_BAD_FIELD_ERROR, MYF(0), (*res)->name,
                        session->where());
-              return(1);
+              return 1;
             }
 
             set_field(new_field);
@@ -841,8 +815,6 @@ bool Item_field::fix_fields(Session *session, Item **reference)
               Item_field created by the parser with the new Item_ref.
             */
             Item_ref *rf= new Item_ref(context, db_name,table_name,field_name);
-            if (!rf)
-              return 1;
             *reference= rf;
             /*
               Because Item_ref never substitutes itself with other items
@@ -854,13 +826,13 @@ bool Item_field::fix_fields(Session *session, Item **reference)
         }
       }
       if ((ret= fix_outer_field(session, &from_field, reference)) < 0)
-        goto error;
+        return true;
       outer_fixed= true;
       if (!ret)
         goto mark_non_agg_field;
     }
     else if (!from_field)
-      goto error;
+      return true;
 
     if (!outer_fixed && cached_table && cached_table->select_lex &&
         context->select_lex &&
@@ -868,7 +840,7 @@ bool Item_field::fix_fields(Session *session, Item **reference)
     {
       int ret;
       if ((ret= fix_outer_field(session, &from_field, reference)) < 0)
-        goto error;
+        return true;
       outer_fixed= 1;
       if (!ret)
         goto mark_non_agg_field;
@@ -926,13 +898,9 @@ bool Item_field::fix_fields(Session *session, Item **reference)
   fixed= 1;
 mark_non_agg_field:
   return false;
-
-error:
-  context->process_error(session);
-  return true;
 }
 
-Item *Item_field::safe_charset_converter(const CHARSET_INFO * const tocs)
+Item *Item_field::safe_charset_converter(const charset_info_st * const tocs)
 {
   no_const_subst= 1;
   return Item::safe_charset_converter(tocs);
@@ -949,7 +917,6 @@ void Item_field::cleanup()
    */
   field= result_field= 0;
   null_value= false;
-  return;
 }
 
 
@@ -979,11 +946,10 @@ bool Item_field::result_as_int64_t()
 
 Item_equal *Item_field::find_item_equal(COND_EQUAL *cond_equal)
 {
-  Item_equal *item= 0;
   while (cond_equal)
   {
     List<Item_equal>::iterator li(cond_equal->current_level.begin());
-    while ((item= li++))
+    while (Item_equal* item= li++)
     {
       if (item->contains(field))
         return item;
@@ -1197,13 +1163,13 @@ int Item_field::save_in_field(Field *to, bool no_conversions)
     res= field_conv(to,result_field);
     null_value=0;
   }
-  return(res);
+  return res;
 }
 
 
-bool Item_field::send(plugin::Client *client, String *)
+void Item_field::send(plugin::Client *client, String *)
 {
-  return client->store(result_field);
+  client->store(result_field);
 }
 
 
@@ -1214,9 +1180,7 @@ void Item_field::update_null_value()
     popping up.
   */
   Session *session= field->getTable()->in_use;
-  int no_errors;
-
-  no_errors= session->no_errors;
+  int no_errors= session->no_errors;
   session->no_errors= 1;
   Item::update_null_value();
   session->no_errors= no_errors;
@@ -1255,12 +1219,9 @@ Item *Item_field::update_value_transformer(unsigned char *select_arg)
     List<Item> *all_fields= &select->join->all_fields;
     Item **ref_pointer_array= select->ref_pointer_array;
     int el= all_fields->size();
-    Item_ref *ref;
-
     ref_pointer_array[el]= (Item*)this;
     all_fields->push_front((Item*)this);
-    ref= new Item_ref(&select->context, ref_pointer_array + el,
-                      table_name, field_name);
+    Item_ref* ref= new Item_ref(&select->context, ref_pointer_array + el, table_name, field_name);
     return ref;
   }
   return this;
