@@ -46,14 +46,15 @@
 #include <drizzled/select_exists_subselect.h>
 #include <drizzled/select_union.h>
 #include <drizzled/sql_lex.h>
+#include <drizzled/system_variables.h>
 
 namespace drizzled {
 
 extern plugin::StorageEngine *myisam_engine;
 
-inline Item * and_items(Item* cond, Item *item)
+inline Item* and_items(Item* cond, Item *item)
 {
-  return (cond? (new Item_cond_and(cond, item)) : item);
+  return cond ? new Item_cond_and(cond, item) : item;
 }
 
 Item_subselect::Item_subselect() :
@@ -148,14 +149,12 @@ void Item_subselect::cleanup()
     engine->cleanup();
   reset();
   value_assigned= 0;
-  return;
 }
 
 void Item_singlerow_subselect::cleanup()
 {
   value= 0; row= 0;
   Item_subselect::cleanup();
-  return;
 }
 
 
@@ -169,7 +168,6 @@ void Item_in_subselect::cleanup()
   }
   first_execution= true;
   Item_subselect::cleanup();
-  return;
 }
 
 Item_subselect::~Item_subselect()
@@ -180,7 +178,7 @@ Item_subselect::~Item_subselect()
 Item_subselect::trans_res
 Item_subselect::select_transformer(Join *)
 {
-  return(RES_OK);
+  return RES_OK;
 }
 
 
@@ -352,7 +350,7 @@ bool Item_in_subselect::exec()
   {
     /* Always compute IN for the first row as the cache is not valid for it. */
     if (!first_execution)
-      return(false);
+      return false;
     first_execution= false;
   }
 
@@ -420,7 +418,6 @@ Item_singlerow_subselect::Item_singlerow_subselect(Select_Lex *select_lex)
   init(select_lex, new select_singlerow_subselect(this));
   maybe_null= 1;
   max_columns= UINT_MAX;
-  return;
 }
 
 Select_Lex *
@@ -466,8 +463,6 @@ Item_maxmin_subselect::Item_maxmin_subselect(Session *session_param,
     session here
   */
   session= session_param;
-
-  return;
 }
 
 void Item_maxmin_subselect::cleanup()
@@ -483,7 +478,6 @@ void Item_maxmin_subselect::cleanup()
     value will be found.
   */
   was_values= true;
-  return;
 }
 
 
@@ -729,15 +723,15 @@ bool Item_in_subselect::test_limit(Select_Lex_Unit *unit_arg)
 {
   if (unit_arg->fake_select_lex &&
       unit_arg->fake_select_lex->test_limit())
-    return(1);
+    return 1;
 
   Select_Lex *sl= unit_arg->first_select();
   for (; sl; sl= sl->next_select())
   {
     if (sl->test_limit())
-      return(1);
+      return 1;
   }
-  return(0);
+  return 0;
 }
 
 Item_in_subselect::Item_in_subselect(Item * left_exp,
@@ -1111,18 +1105,14 @@ Item_in_subselect::single_value_transformer(Join *join,
       As far as  Item_ref_in_optimizer do not substitute itself on fix_fields
       we can use same item for all selects.
     */
-    expr= new Item_direct_ref(&select_lex->context,
-                              (Item**)optimizer->get_cache(),
-			      (char *)"<no matter>",
-			      (char *)in_left_expr_name);
+    expr= new Item_direct_ref(&select_lex->context, (Item**)optimizer->get_cache(), "<no matter>", in_left_expr_name);
 
     master_unit->uncacheable.set(UNCACHEABLE_DEPENDENT);
   }
 
   if (!abort_on_null && left_expr->maybe_null && !pushed_cond_guards)
   {
-    if (!(pushed_cond_guards= (bool*)join->session->getMemRoot()->allocate(sizeof(bool))))
-      return(RES_ERROR);
+    pushed_cond_guards= new (join->session->mem) bool;
     pushed_cond_guards[0]= true;
   }
 
@@ -1184,13 +1174,7 @@ Item_in_subselect::single_value_in_to_exists_transformer(Join * join, const Comp
       select_lex->group_list.elements)
   {
     bool tmp;
-    Item *item= func->create(expr,
-                             new Item_ref_null_helper(&select_lex->context,
-                                                      this,
-                                                      select_lex->
-                                                      ref_pointer_array,
-                                                      (char *)"<ref>",
-                                                      this->full_name()));
+    Item *item= func->create(expr, new Item_ref_null_helper(&select_lex->context, this, select_lex->ref_pointer_array, "<ref>", this->full_name()));
     if (!abort_on_null && left_expr->maybe_null)
     {
       /*
@@ -1228,9 +1212,7 @@ Item_in_subselect::single_value_in_to_exists_transformer(Join * join, const Comp
       bool tmp;
       Item *having= item, *orig_item= item;
       select_lex->item_list.clear();
-      select_lex->item_list.push_back(new Item_int("Not_used",
-                                                   (int64_t) 1,
-                                                   MY_INT64_NUM_DECIMAL_DIGITS));
+      select_lex->item_list.push_back(new Item_int("Not_used", 1, MY_INT64_NUM_DECIMAL_DIGITS));
       select_lex->ref_pointer_array[0]= &select_lex->item_list.front();
 
       item= func->create(expr, item);
@@ -1238,11 +1220,7 @@ Item_in_subselect::single_value_in_to_exists_transformer(Join * join, const Comp
       {
 	having= new Item_is_not_null_test(this, having);
         if (left_expr->maybe_null)
-        {
-          if (!(having= new Item_func_trig_cond(having,
-                                                get_cond_guard(0))))
-            return(RES_ERROR);
-        }
+          having= new Item_func_trig_cond(having, get_cond_guard(0));
 	/*
 	  Item_is_not_null_test can't be changed during fix_fields()
 	  we can assign select_lex->having here, and pass 0 as last
@@ -1260,18 +1238,14 @@ Item_in_subselect::single_value_in_to_exists_transformer(Join * join, const Comp
         select_lex->having_fix_field= 0;
         if (tmp)
 	  return(RES_ERROR);
-	item= new Item_cond_or(item,
-			       new Item_func_isnull(orig_item));
+	item= new Item_cond_or(item, new Item_func_isnull(orig_item));
       }
       /*
         If we may encounter NULL IN (SELECT ...) and care whether subquery
         result is NULL or false, wrap condition in a trig_cond.
       */
       if (!abort_on_null && left_expr->maybe_null)
-      {
-        if (!(item= new Item_func_trig_cond(item, get_cond_guard(0))))
-          return(RES_ERROR);
-      }
+        item= new Item_func_trig_cond(item, get_cond_guard(0));
       /*
         TODO: figure out why the following is done here in
         single_value_transformer but there is no corresponding action in
@@ -1303,19 +1277,10 @@ Item_in_subselect::single_value_in_to_exists_transformer(Join * join, const Comp
 	  we can assign select_lex->having here, and pass 0 as last
 	  argument (reference) to fix_fields()
 	*/
-        Item *new_having=
-          func->create(expr,
-                       new Item_ref_null_helper(&select_lex->context, this,
-                                            select_lex->ref_pointer_array,
-                                            (char *)"<no matter>",
-                                            (char *)"<result>"));
+        Item *new_having= func->create(expr, new Item_ref_null_helper(&select_lex->context, this, select_lex->ref_pointer_array, "<no matter>", "<result>"));
         if (!abort_on_null && left_expr->maybe_null)
-        {
-          if (!(new_having= new Item_func_trig_cond(new_having,
-                                                    get_cond_guard(0))))
-            return(RES_ERROR);
-        }
-        new_having->name= (char*)in_having_cond;
+          new_having= new Item_func_trig_cond(new_having, get_cond_guard(0));
+        new_having->name= in_having_cond;
 	select_lex->having= join->having= new_having;
 	select_lex->having_fix_field= 1;
 
@@ -1390,9 +1355,7 @@ Item_in_subselect::row_value_transformer(Join *join)
 
     if (!abort_on_null && left_expr->maybe_null && !pushed_cond_guards)
     {
-      if (!(pushed_cond_guards= (bool*)join->session->getMemRoot()->allocate(sizeof(bool) *
-                                                        left_expr->cols())))
-        return(RES_ERROR);
+      pushed_cond_guards= new (join->session->mem) bool[left_expr->cols()];
       for (uint32_t i= 0; i < cols_num; i++)
         pushed_cond_guards[i]= true;
     }
@@ -1469,27 +1432,24 @@ Item_in_subselect::row_value_in_to_exists_transformer(Join * join)
                          Item_ref(&select_lex->context,
                                   (*optimizer->get_cache())->
                                   addr(i),
-                                  (char *)"<no matter>",
-                                  (char *)in_left_expr_name),
+                                  "<no matter>",
+                                  in_left_expr_name),
                          new
                          Item_ref(&select_lex->context,
                                   select_lex->ref_pointer_array + i,
-                                  (char *)"<no matter>",
-                                  (char *)"<list ref>")
+                                  "<no matter>",
+                                  "<list ref>")
                         );
       Item *item_isnull=
         new Item_func_isnull(new
                              Item_ref(&select_lex->context,
                                       select_lex->ref_pointer_array+i,
-                                      (char *)"<no matter>",
-                                      (char *)"<list ref>")
+                                      "<no matter>",
+                                      "<list ref>")
                             );
       Item *col_item= new Item_cond_or(item_eq, item_isnull);
       if (!abort_on_null && left_expr->element_index(i)->maybe_null)
-      {
-        if (!(col_item= new Item_func_trig_cond(col_item, get_cond_guard(i))))
-          return(RES_ERROR);
-      }
+        col_item= new Item_func_trig_cond(col_item, get_cond_guard(i));
       having_item= and_items(having_item, col_item);
 
       Item *item_nnull_test=
@@ -1497,13 +1457,11 @@ Item_in_subselect::row_value_in_to_exists_transformer(Join * join)
                                    new Item_ref(&select_lex->context,
                                                 select_lex->
                                                 ref_pointer_array + i,
-                                                (char *)"<no matter>",
-                                                (char *)"<list ref>"));
+                                                "<no matter>",
+                                                "<list ref>"));
       if (!abort_on_null && left_expr->element_index(i)->maybe_null)
       {
-        if (!(item_nnull_test=
-              new Item_func_trig_cond(item_nnull_test, get_cond_guard(i))))
-          return(RES_ERROR);
+        item_nnull_test= new Item_func_trig_cond(item_nnull_test, get_cond_guard(i));
       }
       item_having_part2= and_items(item_having_part2, item_nnull_test);
       item_having_part2->top_level_item();
@@ -1546,14 +1504,14 @@ Item_in_subselect::row_value_in_to_exists_transformer(Join * join)
                          Item_direct_ref(&select_lex->context,
                                          (*optimizer->get_cache())->
                                          addr(i),
-                                         (char *)"<no matter>",
-                                         (char *)in_left_expr_name),
+                                         "<no matter>",
+                                         in_left_expr_name),
                          new
                          Item_direct_ref(&select_lex->context,
                                          select_lex->
                                          ref_pointer_array+i,
-                                         (char *)"<no matter>",
-                                         (char *)"<list ref>")
+                                         "<no matter>",
+                                         "<list ref>")
                         );
       if (!abort_on_null)
       {
@@ -1562,8 +1520,8 @@ Item_in_subselect::row_value_in_to_exists_transformer(Join * join)
                                     new
                                     Item_ref(&select_lex->context,
                                              select_lex->ref_pointer_array + i,
-                                             (char *)"<no matter>",
-                                             (char *)"<list ref>"));
+                                             "<no matter>",
+                                             "<list ref>"));
 
 
         item_isnull= new
@@ -1571,8 +1529,8 @@ Item_in_subselect::row_value_in_to_exists_transformer(Join * join)
                            Item_direct_ref(&select_lex->context,
                                            select_lex->
                                            ref_pointer_array+i,
-                                           (char *)"<no matter>",
-                                           (char *)"<list ref>")
+                                           "<no matter>",
+                                           "<list ref>")
                           );
         item= new Item_cond_or(item, item_isnull);
         /*
@@ -1581,11 +1539,8 @@ Item_in_subselect::row_value_in_to_exists_transformer(Join * join)
         */
         if (left_expr->element_index(i)->maybe_null)
         {
-          if (!(item= new Item_func_trig_cond(item, get_cond_guard(i))))
-            return(RES_ERROR);
-          if (!(having_col_item=
-                  new Item_func_trig_cond(having_col_item, get_cond_guard(i))))
-            return(RES_ERROR);
+          item= new Item_func_trig_cond(item, get_cond_guard(i));
+          having_col_item= new Item_func_trig_cond(having_col_item, get_cond_guard(i));
         }
         having_item= and_items(having_item, having_col_item);
       }
@@ -1730,7 +1685,7 @@ Item_in_subselect::select_in_like_transformer(Join *join, const Comp_creator *fu
   }
 err:
   session->setWhere(save_where);
-  return(res);
+  return res;
 }
 
 
@@ -1793,10 +1748,8 @@ bool Item_in_subselect::setup_engine()
     subselect_single_select_engine *old_engine_ptr;
 
     old_engine_ptr= static_cast<subselect_single_select_engine *>(engine);
-
-    if (!(new_engine= new subselect_hash_sj_engine(session, this,
-                                                   old_engine_ptr)) ||
-        new_engine->init_permanent(unit->get_unit_column_types()))
+    new_engine= new subselect_hash_sj_engine(session, this, old_engine_ptr);
+    if (new_engine->init_permanent(unit->get_unit_column_types()))
     {
       Item_subselect::trans_res new_trans_res;
       /*
@@ -1808,9 +1761,7 @@ bool Item_in_subselect::setup_engine()
       new_engine= NULL;
       exec_method= NOT_TRANSFORMED;
       if (left_expr->cols() == 1)
-        new_trans_res= single_value_in_to_exists_transformer(
-                           old_engine_ptr->join,
-                           Eq_creator::instance());
+        new_trans_res= single_value_in_to_exists_transformer(old_engine_ptr->join, Eq_creator::instance());
       else
         new_trans_res= row_value_in_to_exists_transformer(old_engine_ptr->join);
       res= (new_trans_res != Item_subselect::RES_OK);
@@ -1836,11 +1787,10 @@ bool Item_in_subselect::setup_engine()
       we should set the correct limit if given in the query.
     */
     unit->global_parameters->select_limit= NULL;
-    if ((res= new_engine->init_runtime()))
-      return(res);
+    new_engine->init_runtime();
   }
 
-  return(res);
+  return res;
 }
 
 
@@ -1864,14 +1814,14 @@ bool Item_in_subselect::init_left_expr_cache()
   if (! outer_join || ! outer_join->tables || ! outer_join->join_tab)
     return true;
 
-  if (!(left_expr_cache= new List<Cached_item>))
-    return true;
+  left_expr_cache= new List<Cached_item>;
 
   for (uint32_t i= 0; i < left_expr->cols(); i++)
   {
     Cached_item *cur_item_cache= new_Cached_item(session, left_expr->element_index(i));
-    if (!cur_item_cache || left_expr_cache->push_front(cur_item_cache))
+    if (!cur_item_cache)
       return true;
+		left_expr_cache->push_front(cur_item_cache);
   }
   return false;
 }
@@ -2034,9 +1984,8 @@ int subselect_single_select_engine::prepare()
 {
   if (prepared)
     return 0;
-  join= new Join(session, select_lex->item_list,
-		 select_lex->options | SELECT_NO_UNLOCK, result);
-  if (!join || !result)
+  join= new Join(session, select_lex->item_list, select_lex->options | SELECT_NO_UNLOCK, result);
+  if (not result)
     return 1; /* Fatal error is set already. */
   prepared= 1;
   Select_Lex *save_select= session->lex().current_select;
@@ -2165,12 +2114,10 @@ int subselect_single_select_engine::exec()
       session->lex().current_select= save_select;
       return(join->error ? join->error : 1);
     }
-    if (save_join_if_explain())
-     return(1);
-
+    save_join_if_explain();
     if (item->engine_changed)
     {
-      return(1);
+      return 1;
     }
   }
   if (select_lex->uncacheable.any() &&
@@ -2244,11 +2191,10 @@ int subselect_single_select_engine::exec()
   }
   session->setWhere(save_where);
   session->lex().current_select= save_select;
-  return(0);
+  return 0;
 }
 
-bool 
-subselect_single_select_engine::save_join_if_explain()
+void subselect_single_select_engine::save_join_if_explain()
 {
   /*
     Save this JOIN to join->tmp_join since the original layout will be
@@ -2278,10 +2224,8 @@ subselect_single_select_engine::save_join_if_explain()
     */
     select_lex->uncacheable.set(UNCACHEABLE_EXPLAIN);
     select_lex->master_unit()->uncacheable.set(UNCACHEABLE_EXPLAIN);
-    if (join->init_save_join_tab())
-      return true;
+    join->init_save_join_tab();
   }
-  return false;
 }
 
 
@@ -2419,7 +2363,7 @@ bool subselect_uniquesubquery_engine::copy_ref_key()
       if (top_level)
       {
         /* Partial match on top level */
-        return(1);
+        return 1;
       }
       else
       {
@@ -2446,7 +2390,7 @@ bool subselect_uniquesubquery_engine::copy_ref_key()
       break;
     }
   }
-  return(0);
+  return 0;
 }
 
 
@@ -2489,7 +2433,7 @@ int subselect_uniquesubquery_engine::exec()
 
   /* TODO: change to use of 'full_scan' here? */
   if (copy_ref_key())
-    return(1);
+    return 1;
   if (table->status)
   {
     /*
@@ -2497,7 +2441,7 @@ int subselect_uniquesubquery_engine::exec()
       Can be set in copy_ref_key.
     */
     ((Item_in_subselect *) item)->value= 0;
-    return(0);
+    return 0;
   }
 
   if (null_keypart)
@@ -2610,7 +2554,7 @@ int subselect_indexsubquery_engine::exec()
 
   /* Copy the ref key and check for nulls... */
   if (copy_ref_key())
-    return(1);
+    return 1;
 
   if (table->status)
   {
@@ -2619,7 +2563,7 @@ int subselect_indexsubquery_engine::exec()
       Can be set in copy_ref_key.
     */
     ((Item_in_subselect *) item)->value= 0;
-    return(0);
+    return 0;
   }
 
   if (null_keypart)
@@ -2778,7 +2722,6 @@ void subselect_union_engine::print(String *str)
 
 void subselect_uniquesubquery_engine::print(String *str)
 {
-  const char *table_name= tab->table->getShare()->getTableName();
   str->append(STRING_WITH_LEN("<primary_index_lookup>("));
   tab->ref.items[0]->print(str);
   str->append(STRING_WITH_LEN(" in "));
@@ -2791,10 +2734,9 @@ void subselect_uniquesubquery_engine::print(String *str)
     str->append(STRING_WITH_LEN("<temporary table>"));
   }
   else
-    str->append(table_name, tab->table->getShare()->getTableNameSize());
-  KeyInfo *key_info= tab->table->key_info+ tab->ref.key;
+    str->append(tab->table->getShare()->getTableNameRef());
   str->append(STRING_WITH_LEN(" on "));
-  str->append(key_info->name);
+  str->append(tab->table->key_info[tab->ref.key].name);
   if (cond)
   {
     str->append(STRING_WITH_LEN(" where "));
@@ -2832,7 +2774,7 @@ void subselect_indexsubquery_engine::print(String *str)
   str->append(STRING_WITH_LEN("<index_lookup>("));
   tab->ref.items[0]->print(str);
   str->append(STRING_WITH_LEN(" in "));
-  str->append(tab->table->getShare()->getTableName(), tab->table->getShare()->getTableNameSize());
+  str->append(tab->table->getShare()->getTableNameRef());
   KeyInfo *key_info= tab->table->key_info+ tab->ref.key;
   str->append(STRING_WITH_LEN(" on "));
   str->append(key_info->name);
@@ -3021,14 +2963,11 @@ bool subselect_hash_sj_engine::init_permanent(List<Item> *tmp_columns)
     result stream in a temporary table. The temporary table itself is
     managed (created/filled/etc) internally by the interceptor.
   */
-  if (!(tmp_result_sink= new select_union))
-    return(true);
+  tmp_result_sink= new select_union;
 
-  if (tmp_result_sink->create_result_table(
-                         session, tmp_columns, true,
-                         session->options | TMP_TABLE_ALL_COLUMNS,
-                         "materialized subselect"))
-    return(true);
+  if (tmp_result_sink->create_result_table(session, tmp_columns, true, 
+    session->options | TMP_TABLE_ALL_COLUMNS, "materialized subselect"))
+    return true;
 
   tmp_table= tmp_result_sink->table;
   tmp_key= tmp_table->key_info;
@@ -3051,7 +2990,7 @@ bool subselect_hash_sj_engine::init_permanent(List<Item> *tmp_columns)
     tmp_table= NULL;
     delete result;
     result= NULL;
-    return(true);
+    return true;
   }
   result= tmp_result_sink;
 
@@ -3071,20 +3010,13 @@ bool subselect_hash_sj_engine::init_permanent(List<Item> *tmp_columns)
     - here we initialize only those members that are used by
       subselect_uniquesubquery_engine, so these objects are incomplete.
   */
-  if (!(tab= (JoinTable*) session->getMemRoot()->allocate(sizeof(JoinTable))))
-    return(true);
-  new (tab) JoinTable();
+  tab= new (session->mem) JoinTable;
   tab->table= tmp_table;
   tab->ref.key= 0; /* The only temp table index. */
   tab->ref.key_length= tmp_key->key_length;
-  if (!(tab->ref.key_buff=
-        (unsigned char*) session->calloc(ALIGN_SIZE(tmp_key->key_length) * 2)) ||
-      !(tab->ref.key_copy=
-        (StoredKey**) session->getMemRoot()->allocate((sizeof(StoredKey*) *
-                                  (tmp_key_parts + 1)))) ||
-      !(tab->ref.items=
-        (Item**) session->getMemRoot()->allocate(sizeof(Item*) * tmp_key_parts)))
-    return(true);
+  tab->ref.key_buff= (unsigned char*) session->mem.calloc(ALIGN_SIZE(tmp_key->key_length) * 2);
+  tab->ref.key_copy= new (session->mem) StoredKey*[tmp_key_parts + 1];
+  tab->ref.items= new (session->mem) Item*[tmp_key_parts];
 
   KeyPartInfo *cur_key_part= tmp_key->key_part;
   StoredKey **ref_key= tab->ref.key_copy;
@@ -3110,7 +3042,7 @@ bool subselect_hash_sj_engine::init_permanent(List<Item> *tmp_columns)
   tab->ref.key_err= 1;
   tab->ref.key_parts= tmp_key_parts;
 
-  return(false);
+  return false;
 }
 
 
@@ -3122,7 +3054,7 @@ bool subselect_hash_sj_engine::init_permanent(List<Item> *tmp_columns)
   @retval false if success
 */
 
-bool subselect_hash_sj_engine::init_runtime()
+void subselect_hash_sj_engine::init_runtime()
 {
   /*
     Create and optimize the JOIN that will be used to materialize
@@ -3132,7 +3064,6 @@ bool subselect_hash_sj_engine::init_runtime()
   /* Let our engine reuse this query plan for materialization. */
   materialize_join= materialize_engine->join;
   materialize_join->change_result(result);
-  return false;
 }
 
 
@@ -3189,8 +3120,7 @@ int subselect_hash_sj_engine::exec()
     if ((res= materialize_join->optimize()))
       goto err;
 
-    if (materialize_engine->save_join_if_explain())
-      goto err;
+    materialize_engine->save_join_if_explain();
 
     materialize_join->exec();
     if ((res= test(materialize_join->error || session->is_fatal_error)))
@@ -3218,7 +3148,7 @@ int subselect_hash_sj_engine::exec()
       empty_result_set= true;
       item_in->value= false;
       /* TODO: check we need this: item_in->null_value= false; */
-      return(false);
+      return false;
     }
     /* Set tmp_param only if its usable, i.e. tmp_param->copy_field != NULL. */
     tmp_param= &(item_in->unit->outer_select()->join->tmp_table_param);
@@ -3228,7 +3158,7 @@ int subselect_hash_sj_engine::exec()
 err:
     session->lex().current_select= save_select;
     if (res)
-      return(res);
+      return res;
   }
 
   /*
