@@ -22,12 +22,8 @@
 
 #include <drizzled/optimizer/access_method.h>
 
-class Session;
-
-namespace drizzled
-{
-namespace optimizer
-{
+namespace drizzled {
+namespace optimizer {
 
 /**
  * @class Scan
@@ -37,14 +33,8 @@ namespace optimizer
 class Scan : public AccessMethod
 {
 public:
-  Scan() {}
-
-  bool getStats(Table *table,
-                JoinTable *join_tab);
-
+  void getStats(Table&, JoinTable&);
 };
 
 } /* end namespace optimizer */
-
 } /* end namespace drizzled */
-
