@@ -26,13 +26,14 @@
 #include <drizzled/current_session.h>
 #include <drizzled/key.h>
 #include <drizzled/table.h>
+#include <drizzled/util/test.h>
+#include <drizzled/system_variables.h>
 
 #include <fcntl.h>
 
 using namespace std;
 
-namespace drizzled
-{
+namespace drizzled {
 
 
 optimizer::QuickRangeSelect::QuickRangeSelect(Session *session,
@@ -61,7 +62,7 @@ optimizer::QuickRangeSelect::QuickRangeSelect(Session *session,
   index= key_nr;
   head= table;
   key_part_info= head->key_info[index].key_part;
-  my_init_dynamic_array(&ranges, sizeof(optimizer::QuickRange*), 16, 16);
+  ranges.init(sizeof(optimizer::QuickRange*), 16, 16);
 
   /* 'session' is not accessible in QuickRangeSelect::reset(). */
   mrr_buf_size= session->variables.read_rnd_buff_size;
@@ -69,7 +70,7 @@ optimizer::QuickRangeSelect::QuickRangeSelect(Session *session,
   if (! no_alloc && ! parent_alloc)
   {
     // Allocates everything through the internal memroot
-    memory::init_sql_alloc(&alloc, session->variables.range_alloc_block_size, 0);
+    alloc.init(session->variables.range_alloc_block_size);
     session->mem_root= &alloc;
   }
   else
@@ -120,7 +121,7 @@ optimizer::QuickRangeSelect::~QuickRangeSelect()
         delete cursor;
       }
     }
-    delete_dynamic(&ranges); /* ranges are allocated in alloc */
+    ranges.free(); /* ranges are allocated in alloc */
     delete column_bitmap;
     alloc.free_root(MYF(0));
   }
@@ -130,8 +131,9 @@ optimizer::QuickRangeSelect::~QuickRangeSelect()
 
 int optimizer::QuickRangeSelect::init_ror_merged_scan(bool reuse_handler)
 {
-  Cursor *save_file= cursor, *org_file;
-  Session *session;
+  Cursor* org_file;
+  Cursor* save_file= cursor;
+  Session* session;
 
   in_ror_merged_scan= 1;
   if (reuse_handler)
@@ -152,7 +154,7 @@ int optimizer::QuickRangeSelect::init_ror_merged_scan(bool reuse_handler)
   }
 
   session= head->in_use;
-  if (! (cursor= head->cursor->clone(session->mem_root)))
+  if (not (cursor= head->cursor->clone(session->mem_root)))
   {
     /*
       Manually set the error flag. Note: there seems to be quite a few
@@ -190,7 +192,7 @@ end:
   org_file= head->cursor;
   head->cursor= cursor;
   /* We don't have to set 'head->keyread' here as the 'cursor' is unique */
-  if (! head->no_keyread)
+  if (not head->no_keyread)
   {
     head->key_read= 1;
     head->mark_columns_used_by_index(index);
@@ -462,15 +464,11 @@ optimizer::QuickSelectDescending::QuickSelectDescending(optimizer::QuickRangeSel
   rev_it= rev_ranges.begin();
 
   /* Remove EQ_RANGE flag for keys that are not using the full key */
-  for (vector<optimizer::QuickRange *>::iterator it= rev_ranges.begin();
-       it != rev_ranges.end();
-       ++it)
+  BOOST_FOREACH(QuickRange* it, rev_ranges)
   {
-    optimizer::QuickRange *r= *it;
-    if ((r->flag & EQ_RANGE) &&
-        head->key_info[index].key_length != r->max_length)
+    if ((it->flag & EQ_RANGE) && head->key_info[index].key_length != it->max_length)
     {
-      r->flag&= ~EQ_RANGE;
+      it->flag&= ~EQ_RANGE;
     }
   }
   q->dont_free= 1; // Don't free shared mem
