@@ -20,10 +20,11 @@
 
 #pragma once
 
+#include <boost/lexical_cast.hpp>
 #include <drizzled/field.h>
 #include <drizzled/plugin/client/concurrent.h>
 #include <drizzled/sql/result_set.h>
-#include <iostream>
+#include <iosfwd>
 
 namespace drizzled {
 namespace plugin {
@@ -43,9 +44,9 @@ public:
   {
   }
 
-  virtual bool sendFields(List<Item> *list)
+  virtual void sendFields(List<Item>& list)
   {
-    List<Item>::iterator it(list->begin());
+    List<Item>::iterator it(list.begin());
 
     column= 0;
     max_column= 0;
@@ -56,9 +57,9 @@ public:
       item->make_field(&field);
       max_column++;
     }
-    _result_set->createRow();
-
-    return false;
+    _result_set->setColumnCount(max_column);
+    // Moved to checkRowBegin()
+    //_result_set->createRow();
   }
 
   virtual void sendError(drizzled::error_t error_code, const char *error_message)
@@ -66,17 +67,22 @@ public:
     _result_set->pushException(sql::Exception(error_message, error_code));
   }
 
-  virtual void checkRowEnd()
+  virtual void checkRowBegin()
   {
-    if (++column % max_column == 0)
+    if (currentColumn() == 0)
     {
       _result_set->createRow();
     }
   }
 
+virtual void checkRowEnd()
+  {
+    column++;
+  }
+
   using Client::store;
 
-  virtual bool store(Field *from)
+  virtual void store(Field *from)
   {
     if (from->is_null())
       return store();
@@ -88,59 +94,53 @@ public:
     return store(str.ptr(), str.length());
   }
 
-  virtual bool store()
+  virtual void store()
   {
+    checkRowBegin();
     _result_set->setColumnNull(currentColumn());
-
     checkRowEnd();
-
-    return false;
   }
 
-  virtual bool store(int32_t from)
+  virtual void store(int32_t from)
   {
+    checkRowBegin();
     _result_set->setColumn(currentColumn(), boost::lexical_cast<std::string>(from));
     checkRowEnd();
-
-    return false;
   }
 
-  virtual bool store(uint32_t from)
+  virtual void store(uint32_t from)
   {
+    checkRowBegin();
     _result_set->setColumn(currentColumn(), boost::lexical_cast<std::string>(from));
     checkRowEnd();
-
-    return false;
   }
 
-  virtual bool store(int64_t from)
+  virtual void store(int64_t from)
   {
+    checkRowBegin();
     _result_set->setColumn(currentColumn(), boost::lexical_cast<std::string>(from));
     checkRowEnd();
-
-    return false;
   }
 
-  virtual bool store(uint64_t from)
+  virtual void store(uint64_t from)
   {
+    checkRowBegin();
     _result_set->setColumn(currentColumn(), boost::lexical_cast<std::string>(from));
     checkRowEnd();
-
-    return false;
   }
 
-  virtual bool store(double from, uint32_t decimals, String *buffer)
+  virtual void store(double from, uint32_t decimals, String *buffer)
   {
+    checkRowBegin();
     buffer->set_real(from, decimals, &my_charset_bin);
     return store(buffer->ptr(), buffer->length());
   }
 
-  virtual bool store(const char *from, size_t length)
+  virtual void store(const char *from, size_t length)
   {
+    checkRowBegin();
     _result_set->setColumn(currentColumn(), std::string(from, length));
     checkRowEnd();
-
-    return false;
   }
   
   inline uint32_t currentColumn() const
