@@ -40,33 +40,29 @@
 #include <drizzled/session.h>
 #include <drizzled/error.h>
 #include <drizzled/gettext.h>
-#include <drizzled/unireg.h>
 #include <drizzled/data_home.h>
 #include <drizzled/errmsg_print.h>
 #include <drizzled/xid.h>
 #include <drizzled/sql_table.h>
-#include <drizzled/global_charset_info.h>
 #include <drizzled/charset.h>
 #include <drizzled/internal/my_sys.h>
 #include <drizzled/table_proto.h>
 #include <drizzled/plugin/event_observer.h>
-#include <drizzled/internal_error_handler.h>
 #include <drizzled/table/shell.h>
 #include <drizzled/message/cache.h>
 #include <drizzled/key.h>
+#include <drizzled/session/transactions.h>
+#include <drizzled/open_tables_state.h>
 
 #include <boost/algorithm/string/compare.hpp>
 
 static bool shutdown_has_begun= false; // Once we put in the container for the vector/etc for engines this will go away.
 
-namespace drizzled
-{
+namespace drizzled {
+namespace plugin {
 
-namespace plugin
-{
-
-static EngineVector vector_of_engines;
-static EngineVector vector_of_schema_engines;
+static EngineVector g_engines;
+static EngineVector g_schema_engines;
 
 const std::string DEFAULT_STRING("default");
 const std::string UNKNOWN_STRING("UNKNOWN");
@@ -76,10 +72,10 @@ static std::set<std::string> set_of_table_definition_ext;
 
 EngineVector &StorageEngine::getSchemaEngines()
 {
-  return vector_of_schema_engines;
+  return g_schema_engines;
 }
 
-StorageEngine::StorageEngine(const std::string name_arg,
+StorageEngine::StorageEngine(const std::string &name_arg,
                              const std::bitset<HTON_BIT_SIZE> &flags_arg) :
   Plugin(name_arg, "StorageEngine"),
   MonitoredInTransaction(), /* This gives the storage engine a "slot" or ID */
@@ -97,25 +93,14 @@ void StorageEngine::setTransactionReadWrite(Session& session)
   statement_ctx.markModifiedNonTransData();
 }
 
-
 int StorageEngine::renameTable(Session &session, const identifier::Table &from, const identifier::Table &to)
 {
-  int error;
   setTransactionReadWrite(session);
-
   if (unlikely(plugin::EventObserver::beforeRenameTable(session, from, to)))
-  {
+    return ER_EVENT_OBSERVER_PLUGIN;
+  int error= doRenameTable(session, from, to);
+  if (unlikely(plugin::EventObserver::afterRenameTable(session, from, to, error)))
     error= ER_EVENT_OBSERVER_PLUGIN;
-  }
-  else
-  {
-    error =  doRenameTable(session, from, to);
-    if (unlikely(plugin::EventObserver::afterRenameTable(session, from, to, error)))
-    {
-      error= ER_EVENT_OBSERVER_PLUGIN;
-    }
-  }
-  
   return error;
 }
 
@@ -135,7 +120,6 @@ int StorageEngine::renameTable(Session &session, const identifier::Table &from,
     !0  Error
 */
 int StorageEngine::doDropTable(Session&, const identifier::Table &identifier)
-                               
 {
   int error= 0;
   int enoent_or_zero= ENOENT;                   // Error if no file was deleted
@@ -162,8 +146,7 @@ int StorageEngine::doDropTable(Session&, const identifier::Table &identifier)
 
 bool StorageEngine::addPlugin(StorageEngine *engine)
 {
-
-  vector_of_engines.push_back(engine);
+  g_engines.push_back(engine);
 
   if (engine->getTableDefinitionFileExtension().length())
   {
@@ -172,51 +155,30 @@ bool StorageEngine::addPlugin(StorageEngine *engine)
   }
 
   if (engine->check_flag(HTON_BIT_SCHEMA_DICTIONARY))
-    vector_of_schema_engines.push_back(engine);
+    g_schema_engines.push_back(engine);
 
   return false;
 }
 
 void StorageEngine::removePlugin(StorageEngine *)
 {
-  if (shutdown_has_begun == false)
-  {
-    vector_of_engines.clear();
-    vector_of_schema_engines.clear();
-
-    shutdown_has_begun= true;
-  }
+  if (shutdown_has_begun)
+    return;
+  shutdown_has_begun= true;
+  g_engines.clear();
+  g_schema_engines.clear();
 }
 
-class FindEngineByName
-  : public std::unary_function<StorageEngine *, bool>
-{
-  const std::string &predicate;
-
-public:
-  explicit FindEngineByName(const std::string &target_arg) :
-    predicate(target_arg)
-  {
-  }
-
-  result_type operator() (argument_type engine)
-  {
-    return boost::iequals(engine->getName(), predicate);
-  }
-};
-
 StorageEngine *StorageEngine::findByName(const std::string &predicate)
 {
-  EngineVector::iterator iter= std::find_if(vector_of_engines.begin(),
-                                            vector_of_engines.end(),
-                                            FindEngineByName(predicate));
-  if (iter != vector_of_engines.end())
+  BOOST_FOREACH(EngineVector::reference it, g_engines)
   {
-    StorageEngine *engine= *iter;
-    if (engine->is_user_selectable())
-      return engine;
+    if (not boost::iequals(it->getName(), predicate))
+      continue;
+    if (it->is_user_selectable())
+      return it;
+    break;
   }
-
   return NULL;
 }
 
@@ -224,60 +186,32 @@ StorageEngine *StorageEngine::findByName(Session& session, const std::string &pr
 {
   if (boost::iequals(predicate, DEFAULT_STRING))
     return session.getDefaultStorageEngine();
-
-  EngineVector::iterator iter= std::find_if(vector_of_engines.begin(),
-                                            vector_of_engines.end(),
-                                            FindEngineByName(predicate));
-  if (iter != vector_of_engines.end())
-  {
-    StorageEngine *engine= *iter;
-    if (engine->is_user_selectable())
-      return engine;
-  }
-
-  return NULL;
+  return findByName(predicate);
 }
 
-class StorageEngineCloseConnection : public std::unary_function<StorageEngine *, void>
-{
-  Session *session;
-public:
-  StorageEngineCloseConnection(Session *session_arg) : session(session_arg) {}
-  /*
-    there's no need to rollback here as all transactions must
-    be rolled back already
-  */
-  inline result_type operator() (argument_type engine)
-  {
-    if (*session->getEngineData(engine))
-      engine->close_connection(session);
-  }
-};
-
 /**
   @note
     don't bother to rollback here, it's done already
 */
-void StorageEngine::closeConnection(Session* session)
+void StorageEngine::closeConnection(Session& session)
 {
-  std::for_each(vector_of_engines.begin(), vector_of_engines.end(),
-                StorageEngineCloseConnection(session));
+  BOOST_FOREACH(EngineVector::reference it, g_engines)
+  {
+    if (*session.getEngineData(it))
+      it->close_connection(&session);
+  }
 }
 
 bool StorageEngine::flushLogs(StorageEngine *engine)
 {
-  if (engine == NULL)
+  if (not engine)
   {
-    if (std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
-                     std::mem_fun(&StorageEngine::flush_logs))
-        != vector_of_engines.begin())
-      return true;
-  }
-  else
-  {
-    if (engine->flush_logs())
+    if (std::find_if(g_engines.begin(), g_engines.end(), std::mem_fun(&StorageEngine::flush_logs))
+        != g_engines.begin()) // Shouldn't this be .end()?
       return true;
   }
+  else if (engine->flush_logs())
+    return true;
   return false;
 }
 
@@ -309,23 +243,6 @@ public:
   }
 };
 
-class StorageEngineDoesTableExist: public std::unary_function<StorageEngine *, bool>
-{
-  Session& session;
-  const identifier::Table &identifier;
-
-public:
-  StorageEngineDoesTableExist(Session& session_arg, const identifier::Table &identifier_arg) :
-    session(session_arg), 
-    identifier(identifier_arg) 
-  { }
-
-  result_type operator() (argument_type engine)
-  {
-    return engine->doDoesTableExist(session, identifier);
-  }
-};
-
 /**
   Utility method which hides some of the details of getTableDefinition()
 */
@@ -333,42 +250,31 @@ bool plugin::StorageEngine::doesTableExist(Session &session,
                                            const identifier::Table &identifier,
                                            bool include_temporary_tables)
 {
-  if (include_temporary_tables)
+  if (include_temporary_tables && session.open_tables.doDoesTableExist(identifier))
+      return true;
+  BOOST_FOREACH(EngineVector::reference it, g_engines)
   {
-    if (session.doDoesTableExist(identifier))
+    if (it->doDoesTableExist(session, identifier))
       return true;
   }
-
-  EngineVector::iterator iter=
-    std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
-                 StorageEngineDoesTableExist(session, identifier));
-
-  if (iter == vector_of_engines.end())
-  {
-    return false;
-  }
-
-  return true;
+  return false;
 }
 
 bool plugin::StorageEngine::doDoesTableExist(Session&, const drizzled::identifier::Table&)
 {
-  std::cerr << " Engine was called for doDoesTableExist() and does not implement it: " << this->getName() << "\n";
+  std::cerr << " Engine was called for doDoesTableExist() and does not implement it: " << getName() << "\n";
   assert(0);
   return false;
 }
 
 message::table::shared_ptr StorageEngine::getTableMessage(Session& session,
-                                                          identifier::Table::const_reference identifier,
+                                                          const identifier::Table& identifier,
                                                           bool include_temporary_tables)
 {
-  drizzled::error_t error;
-  error= static_cast<drizzled::error_t>(ENOENT);
-
+  drizzled::error_t error= static_cast<drizzled::error_t>(ENOENT);
   if (include_temporary_tables)
   {
-    Table *table= session.find_temporary_table(identifier);
-    if (table)
+    if (Table *table= session.open_tables.find_temporary_table(identifier))
     {
       return message::table::shared_ptr(new message::Table(*table->getShare()->getTableMessage()));
     }
@@ -381,11 +287,10 @@ message::table::shared_ptr StorageEngine::getTableMessage(Session& session,
   }
 
   message::Table message;
-  EngineVector::iterator iter=
-    std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
-                 StorageEngineGetTableDefinition(session, identifier, message, error));
+  EngineVector::iterator iter= std::find_if(g_engines.begin(), g_engines.end(), 
+    StorageEngineGetTableDefinition(session, identifier, message, error));
 
-  if (iter == vector_of_engines.end())
+  if (iter == g_engines.end())
   {
     return message::table::shared_ptr();
   }
@@ -396,46 +301,16 @@ message::table::shared_ptr StorageEngine::getTableMessage(Session& session,
   return table_message;
 }
 
-/**
-  An interceptor to hijack the text of the error message without
-  setting an error in the thread. We need the text to present it
-  in the form of a warning to the user.
-*/
-
-class Ha_delete_table_error_handler: public Internal_error_handler
-{
-public:
-  Ha_delete_table_error_handler() : Internal_error_handler() {}
-  virtual bool handle_error(drizzled::error_t sql_errno,
-                            const char *message,
-                            DRIZZLE_ERROR::enum_warning_level level,
-                            Session *session);
-  char buff[DRIZZLE_ERRMSG_SIZE];
-};
-
-
-bool
-Ha_delete_table_error_handler::
-handle_error(drizzled::error_t ,
-             const char *message,
-             DRIZZLE_ERROR::enum_warning_level ,
-             Session *)
-{
-  /* Grab the error message */
-  strncpy(buff, message, sizeof(buff)-1);
-  return true;
-}
-
 class DropTableByIdentifier: public std::unary_function<EngineVector::value_type, bool>
 {
-  Session::reference session;
-  identifier::Table::const_reference identifier;
+  Session& session;
+  const identifier::Table& identifier;
   drizzled::error_t &error;
 
 public:
 
-  DropTableByIdentifier(Session::reference session_arg,
-                        identifier::Table::const_reference identifier_arg,
+  DropTableByIdentifier(Session& session_arg,
+                        const identifier::Table& identifier_arg,
                         drizzled::error_t &error_arg) :
     session(session_arg),
     identifier(identifier_arg),
@@ -468,20 +343,20 @@ public:
 };
 
 
-bool StorageEngine::dropTable(Session::reference session,
-                              identifier::Table::const_reference identifier,
+bool StorageEngine::dropTable(Session& session,
+                              const identifier::Table& identifier,
                               drizzled::error_t &error)
 {
   error= EE_OK;
 
-  EngineVector::const_iterator iter= std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
+  EngineVector::const_iterator iter= std::find_if(g_engines.begin(), g_engines.end(),
                                                   DropTableByIdentifier(session, identifier, error));
 
   if (error)
   {
     return false;
   }
-  else if (iter == vector_of_engines.end())
+  else if (iter == g_engines.end())
   {
     error= ER_BAD_TABLE_ERROR;
     return false;
@@ -496,18 +371,12 @@ bool StorageEngine::dropTable(Session& session,
                               const identifier::Table &identifier)
 {
   drizzled::error_t error;
-
-  if (not dropTable(session, identifier, error))
-  {
-    return false;
-  }
-
-  return true;
+  return dropTable(session, identifier, error);
 }
 
-bool StorageEngine::dropTable(Session::reference session,
+bool StorageEngine::dropTable(Session& session,
                               StorageEngine &engine,
-                              identifier::Table::const_reference identifier,
+                              const identifier::Table& identifier,
                               drizzled::error_t &error)
 {
   error= EE_OK;
@@ -528,15 +397,8 @@ bool StorageEngine::dropTable(Session::reference session,
       error= ER_EVENT_OBSERVER_PLUGIN;
     }
   }
-
   drizzled::message::Cache::singleton().erase(identifier);
-
-  if (error)
-  {
-    return false;
-  }
-
-  return true;
+  return not error;
 }
 
 
@@ -591,19 +453,11 @@ bool StorageEngine::createTable(Session &session,
     }
 
     if (error == ER_TABLE_PERMISSION_DENIED)
-    {
       my_error(ER_TABLE_PERMISSION_DENIED, identifier);
-    }
     else if (error)
-    {
-      std::string path;
-      identifier.getSQLPath(path);
-      my_error(ER_CANT_CREATE_TABLE, MYF(ME_BELL+ME_WAITTANG), path.c_str(), error);
-    }
-
+      my_error(ER_CANT_CREATE_TABLE, MYF(ME_BELL+ME_WAITTANG), identifier.getSQLPath().c_str(), error);
     table.delete_table();
   }
-
   return(error == EE_OK);
 }
 
@@ -612,61 +466,30 @@ Cursor *StorageEngine::getCursor(Table &arg)
   return create(arg);
 }
 
-class AddTableIdentifier : 
-  public std::unary_function<StorageEngine *, void>
-{
-  CachedDirectory &directory;
-  const identifier::Schema &identifier;
-  identifier::Table::vector &set_of_identifiers;
-
-public:
-
-  AddTableIdentifier(CachedDirectory &directory_arg, const identifier::Schema &identifier_arg, identifier::Table::vector &of_names) :
-    directory(directory_arg),
-    identifier(identifier_arg),
-    set_of_identifiers(of_names)
-  {
-  }
-
-  result_type operator() (argument_type engine)
-  {
-    engine->doGetTableIdentifiers(directory, identifier, set_of_identifiers);
-  }
-};
-
-
-void StorageEngine::getIdentifiers(Session &session, const identifier::Schema &schema_identifier, identifier::Table::vector &set_of_identifiers)
+void StorageEngine::getIdentifiers(Session &session, const identifier::Schema &schema_identifier, identifier::table::vector &set_of_identifiers)
 {
   CachedDirectory directory(schema_identifier.getPath(), set_of_table_definition_ext);
 
   if (schema_identifier == INFORMATION_SCHEMA_IDENTIFIER)
-  { }
+  { 
+	}
   else if (schema_identifier == DATA_DICTIONARY_IDENTIFIER)
-  { }
-  else
+  { 
+	}
+  else if (directory.fail())
   {
-    if (directory.fail())
-    {
-      errno= directory.getError();
-      if (errno == ENOENT)
-      {
-        std::string path;
-        schema_identifier.getSQLPath(path);
-        my_error(ER_BAD_DB_ERROR, MYF(ME_BELL+ME_WAITTANG), path.c_str());
-      }
-      else
-      {
-        my_error(ER_CANT_READ_DIR, MYF(ME_BELL+ME_WAITTANG), directory.getPath(), errno);
-      }
-
-      return;
-    }
+    errno= directory.getError();
+    if (errno == ENOENT)
+      my_error(ER_BAD_DB_ERROR, MYF(ME_BELL+ME_WAITTANG), schema_identifier.getSQLPath().c_str());
+    else
+      my_error(ER_CANT_READ_DIR, MYF(ME_BELL+ME_WAITTANG), directory.getPath(), errno);
+    return;
   }
 
-  std::for_each(vector_of_engines.begin(), vector_of_engines.end(),
-                AddTableIdentifier(directory, schema_identifier, set_of_identifiers));
+  BOOST_FOREACH(EngineVector::reference it, g_engines)
+    it->doGetTableIdentifiers(directory, schema_identifier, set_of_identifiers);
 
-  session.doGetTableIdentifiers(directory, schema_identifier, set_of_identifiers);
+  session.open_tables.doGetTableIdentifiers(directory, schema_identifier, set_of_identifiers);
 }
 
 class DropTable: public std::unary_function<identifier::Table&, bool>
@@ -687,30 +510,6 @@ public:
   } 
 };
 
-/* This will later be converted to identifier::Tables */
-class DropTables: public std::unary_function<StorageEngine *, void>
-{
-  Session &session;
-  identifier::Table::vector &table_identifiers;
-
-public:
-
-  DropTables(Session &session_arg, identifier::Table::vector &table_identifiers_arg) :
-    session(session_arg),
-    table_identifiers(table_identifiers_arg)
-  { }
-
-  result_type operator() (argument_type engine)
-  {
-    // True returning from DropTable means the table has been successfully
-    // deleted, so it should be removed from the list of tables to drop
-    table_identifiers.erase(std::remove_if(table_identifiers.begin(),
-                                           table_identifiers.end(),
-                                           DropTable(session, engine)),
-                            table_identifiers.end());
-  }
-};
-
 /*
   This only works for engines which use file based DFE.
 
@@ -719,7 +518,7 @@ public:
 void StorageEngine::removeLostTemporaryTables(Session &session, const char *directory)
 {
   CachedDirectory dir(directory, set_of_table_definition_ext);
-  identifier::Table::vector table_identifiers;
+  identifier::table::vector table_identifiers;
 
   if (dir.fail())
   {
@@ -753,8 +552,11 @@ void StorageEngine::removeLostTemporaryTables(Session &session, const char *dire
     }
   }
 
-  std::for_each(vector_of_engines.begin(), vector_of_engines.end(),
-                DropTables(session, table_identifiers));
+  BOOST_FOREACH(EngineVector::reference it, g_engines)
+  {
+    table_identifiers.erase(std::remove_if(table_identifiers.begin(), table_identifiers.end(), DropTable(session, it)),
+      table_identifiers.end());
+  }
 
   /*
     Now we just clean up anything that might left over.
@@ -764,8 +566,8 @@ void StorageEngine::removeLostTemporaryTables(Session &session, const char *dire
   */
   std::set<std::string> all_exts= set_of_table_definition_ext;
 
-  for (EngineVector::iterator iter= vector_of_engines.begin();
-       iter != vector_of_engines.end() ; iter++)
+  for (EngineVector::iterator iter= g_engines.begin();
+       iter != g_engines.end() ; iter++)
   {
     for (const char **ext= (*iter)->bas_ext(); *ext ; ext++)
       all_exts.insert(*ext);
@@ -916,14 +718,14 @@ void StorageEngine::print_error(int error, myf errflag, const Table &table) cons
   {
     String str;
     get_error_message(error, &str);
-    my_error(ER_ROW_IS_REFERENCED_2, MYF(0), str.c_ptr_safe());
+    my_error(ER_ROW_IS_REFERENCED_2, MYF(0), str.c_str());
     return;
   }
   case HA_ERR_NO_REFERENCED_ROW:
   {
     String str;
     get_error_message(error, &str);
-    my_error(ER_NO_REFERENCED_ROW_2, MYF(0), str.c_ptr_safe());
+    my_error(ER_NO_REFERENCED_ROW_2, MYF(0), str.c_str());
     return;
   }
   case HA_ERR_TABLE_DEF_CHANGED:
@@ -960,8 +762,7 @@ void StorageEngine::print_error(int error, myf errflag, const Table &table) cons
     textno= ER_WARN_DATA_OUT_OF_RANGE;
     break;
   case HA_ERR_LOCK_OR_ACTIVE_TRANSACTION:
-    my_message(ER_LOCK_OR_ACTIVE_TRANSACTION,
-               ER(ER_LOCK_OR_ACTIVE_TRANSACTION), MYF(0));
+    my_message(ER_LOCK_OR_ACTIVE_TRANSACTION, ER(ER_LOCK_OR_ACTIVE_TRANSACTION), MYF(0));
     return;
   default:
     {
@@ -972,12 +773,11 @@ void StorageEngine::print_error(int error, myf errflag, const Table &table) cons
       bool temporary= false;
       String str;
       temporary= get_error_message(error, &str);
-      if (!str.is_empty())
+      if (!str.empty())
       {
         const char* engine_name= getName().c_str();
         if (temporary)
-          my_error(ER_GET_TEMPORARY_ERRMSG, MYF(0), error, str.ptr(),
-                   engine_name);
+          my_error(ER_GET_TEMPORARY_ERRMSG, MYF(0), error, str.ptr(), engine_name);
         else
           my_error(ER_GET_ERRMSG, MYF(0), error, str.ptr(), engine_name);
       }
@@ -1107,12 +907,7 @@ int StorageEngine::writeDefinitionFromPath(const identifier::Table &identifier,
 
   if (not success)
   {
-    std::string error_message;
-    identifier.getSQLPath(error_message);
-
-    my_error(ER_CORRUPT_TABLE_DEFINITION, MYF(0),
-             error_message.c_str(),
-             table_message.InitializationErrorString().c_str());
+    my_error(ER_CORRUPT_TABLE_DEFINITION, MYF(0), identifier.getSQLPath().c_str(), table_message.InitializationErrorString().c_str());
     delete output;
 
     if (close(fd) == -1)
@@ -1151,37 +946,17 @@ int StorageEngine::writeDefinitionFromPath(const identifier::Table &identifier,
   return 0;
 }
 
-class CanCreateTable: public std::unary_function<StorageEngine *, bool>
-{
-  const identifier::Table &identifier;
-
-public:
-  CanCreateTable(const identifier::Table &identifier_arg) :
-    identifier(identifier_arg)
-  { }
-
-  result_type operator() (argument_type engine)
-  {
-    return not engine->doCanCreateTable(identifier);
-  }
-};
-
-
 /**
   @note on success table can be created.
 */
 bool StorageEngine::canCreateTable(const identifier::Table &identifier)
 {
-  EngineVector::iterator iter=
-    std::find_if(vector_of_engines.begin(), vector_of_engines.end(),
-                 CanCreateTable(identifier));
-
-  if (iter == vector_of_engines.end())
+  BOOST_FOREACH(EngineVector::reference it, g_engines)
   {
-    return true;
+    if (not it->doCanCreateTable(identifier))
+      return false;
   }
-
-  return false;
+  return true;
 }
 
 bool StorageEngine::readTableFile(const std::string &path, message::Table &table_message)
@@ -1213,11 +988,7 @@ bool StorageEngine::readTableFile(const std::string &path, message::Table &table
 
 std::ostream& operator<<(std::ostream& output, const StorageEngine &engine)
 {
-  output << "StorageEngine:(";
-  output <<  engine.getName();
-  output << ")";
-
-  return output;
+  return output << "StorageEngine:(" <<  engine.getName() << ")";
 }
 
 } /* namespace plugin */
