@@ -21,7 +21,7 @@
 
 #include <drizzled/current_session.h>
 #include <drizzled/gettext.h>
-#include <drizzled/global_charset_info.h>
+#include <drizzled/charset.h>
 #include <drizzled/plugin/table_function.h>
 #include <drizzled/session.h>
 #include <drizzled/show.h>
@@ -41,6 +41,7 @@ void plugin::TableFunction::init()
   proto.set_creation_timestamp(0);
   proto.set_update_timestamp(0);
   message::set_is_replicated(proto, false);
+  message::set_definer(proto, SYSTEM_USER);
 }
 
 bool plugin::TableFunction::addPlugin(plugin::TableFunction *tool)
@@ -160,18 +161,10 @@ plugin::TableFunction::Generator::Generator(Field **arg) :
 
 bool plugin::TableFunction::Generator::sub_populate(uint32_t field_size)
 {
-  bool ret;
-  uint64_t difference;
-
   columns_iterator= columns;
-  ret= populate();
-  difference= columns_iterator - columns;
-
-  if (ret == true)
-  {
-    assert(difference == field_size);
-  }
-
+  bool ret= populate();
+  if (ret)
+    assert(columns_iterator == columns + field_size);
   return ret;
 }
 
@@ -193,8 +186,8 @@ void plugin::TableFunction::Generator::push(const char *arg, uint32_t length)
 {
   assert(columns_iterator);
   assert(*columns_iterator);
-  assert(arg);
-  length= length ? length : strlen(arg);
+  if (arg && not length)
+    length= strlen(arg);
 
   if ((*columns_iterator)->char_length() < length)
     length= (*columns_iterator)->char_length();
@@ -212,35 +205,23 @@ void plugin::TableFunction::Generator::push()
   columns_iterator++;
 }
 
-void plugin::TableFunction::Generator::push(const std::string& arg)
+void plugin::TableFunction::Generator::push(str_ref arg)
 {
-  push(arg.c_str(), arg.length());
+  push(arg.data(), arg.size());
 }
 
 void plugin::TableFunction::Generator::push(bool arg)
 {
   if (arg)
-  {
     (*columns_iterator)->store("YES", 3, scs);
-  }
   else
-  {
     (*columns_iterator)->store("NO", 2, scs);
-  }
-
   columns_iterator++;
 }
 
 bool plugin::TableFunction::Generator::isWild(const std::string &predicate)
 {
-  if (not lex().wild)
-    return false;
-
-  bool match= wild_case_compare(system_charset_info,
-                                predicate.c_str(),
-                                lex().wild->ptr());
-
-  return match;
+  return lex().wild ? wild_case_compare(system_charset_info, predicate.c_str(), lex().wild->ptr()) : false;
 }
 
 } /* namespace drizzled */
