@@ -28,36 +28,26 @@
 #include <drizzled/gettext.h>
 #include <drizzled/plugin/xa_resource_manager.h>
 #include <drizzled/xid.h>
-
+#include <drizzled/errmsg_print.h>
+#include <drizzled/sys_var.h>
 
 #include <string>
 #include <vector>
 #include <algorithm>
 #include <functional>
 
-namespace drizzled
-{
+namespace drizzled {
+namespace plugin {
 
-namespace plugin
-{
-
-static std::vector<XaResourceManager *> xa_resource_managers;
+typedef std::vector<XaResourceManager*> xa_resource_managers_t;
+static xa_resource_managers_t xa_resource_managers;
 
 int XaResourceManager::commitOrRollbackXID(XID *xid, bool commit)
 {
   std::vector<int> results;
-
-  if (commit)
-    transform(xa_resource_managers.begin(), xa_resource_managers.end(), results.begin(),
-              std::bind2nd(std::mem_fun(&XaResourceManager::xaCommitXid), xid));
-  else
-    transform(xa_resource_managers.begin(), xa_resource_managers.end(), results.begin(),
-              std::bind2nd(std::mem_fun(&XaResourceManager::xaRollbackXid), xid));
-
-  if (std::find_if(results.begin(), results.end(), std::bind2nd(std::equal_to<int>(),0)) == results.end())
-    return 1;
-
-  return 0;
+  BOOST_FOREACH(XaResourceManager* it, xa_resource_managers)
+    results.push_back(commit ? it->xaCommitXid(xid) : it->xaRollbackXid(xid));
+  return std::find(results.begin(), results.end(), 0) == results.end();
 }
 
 /**
@@ -174,7 +164,7 @@ int XaResourceManager::recoverAllXids(const XaResourceManager::commit_list_set &
   if (!trans_list)
   {
     errmsg_printf(error::ERROR, ER(ER_OUTOFMEMORY), trans_len*sizeof(XID));
-    return(1);
+    return 1;
   }
 
   if (commit_list.size())
@@ -201,13 +191,13 @@ int XaResourceManager::recoverAllXids(const XaResourceManager::commit_list_set &
                     "drizzled with the --tc-heuristic-recover switch to "
                     "commit or rollback pending transactions."),
                     recover_func.getMyXIDs(), opt_tc_log_file);
-    return(1);
+    return 1;
   }
 
   if (commit_list.size())
     errmsg_printf(error::INFO, _("Crash recovery finished."));
 
-  return(0);
+  return 0;
 }
 
 bool XaResourceManager::addPlugin(XaResourceManager *resource_manager)
