@@ -37,9 +37,13 @@
 #include <drizzled/alter_info.h>
 #include <drizzled/sql_parse.h>
 #include <drizzled/sql_lex.h>
+#include <drizzled/statistics_variables.h>
+#include <drizzled/session/transactions.h>
+#include <drizzled/open_tables_state.h>
+#include <drizzled/table/cache.h>
+#include <drizzled/create_field.h>
 
-namespace drizzled
-{
+namespace drizzled {
 
 extern plugin::StorageEngine *heap_engine;
 extern plugin::StorageEngine *myisam_engine;
@@ -251,7 +255,6 @@ bool insert_query(Session *session,TableList *table_list,
   List_item *values;
   Name_resolution_context *context;
   Name_resolution_context_state ctx_state;
-  thr_lock_type lock_type;
   Item *unused_conds= 0;
 
 
@@ -268,8 +271,6 @@ bool insert_query(Session *session,TableList *table_list,
     return true;
   }
 
-  lock_type= table_list->lock_type;
-
   session->set_proc_info("init");
   session->used_tables=0;
   values= its++;
@@ -549,14 +550,8 @@ static bool prepare_insert_check_table(Session *session, TableList *table_list,
      than INSERT.
   */
 
-  if (setup_tables_and_check_access(session, &session->lex().select_lex.context,
-                                    &session->lex().select_lex.top_join_list,
-                                    table_list,
-                                    &session->lex().select_lex.leaf_tables,
-                                    select_insert))
-    return(true);
-
-  return(false);
+  return setup_tables_and_check_access(session, &session->lex().select_lex.context,
+    &session->lex().select_lex.top_join_list, table_list, &session->lex().select_lex.leaf_tables, select_insert);
 }
 
 
@@ -632,12 +627,11 @@ bool prepare_insert(Session *session, TableList *table_list,
   if (duplic == DUP_UPDATE)
   {
     /* it should be allocated before Item::fix_fields() */
-    if (table_list->set_insert_values(session->mem_root))
-      return(true);
+    table_list->set_insert_values();
   }
 
   if (prepare_insert_check_table(session, table_list, fields, select_insert))
-    return(true);
+    return true;
 
 
   /* Prepare the fields in the statement. */
@@ -685,20 +679,15 @@ bool prepare_insert(Session *session, TableList *table_list,
   }
 
   if (res)
-    return(res);
+    return res;
 
   if (not table)
     table= table_list->table;
 
-  if (not select_insert)
+  if (not select_insert && unique_table(table_list, table_list->next_global, true))
   {
-    TableList *duplicate;
-    if ((duplicate= unique_table(table_list, table_list->next_global, true)))
-    {
-      my_error(ER_UPDATE_TABLE_USED, MYF(0), table_list->alias);
-
-      return true;
-    }
+    my_error(ER_UPDATE_TABLE_USED, MYF(0), table_list->alias);
+    return true;
   }
 
   if (duplic == DUP_UPDATE || duplic == DUP_REPLACE)
@@ -961,7 +950,7 @@ after_n_copied_inc:
 gok_or_after_err:
   if (!table->cursor->has_transactions())
     session->transaction.stmt.markModifiedNonTransData();
-  return(0);
+  return 0;
 
 err:
   info->last_errno= error;
@@ -988,7 +977,7 @@ int check_that_all_fields_are_given_values(Session *session, Table *entry,
 
   for (Field **field=entry->getFields() ; *field ; field++)
   {
-    if (((*field)->isWriteSet()) == false)
+    if (not (*field)->isWriteSet())
     {
       /*
        * If the field doesn't have any default value
@@ -1055,7 +1044,7 @@ bool insert_select_prepare(Session *session)
                            lex->update_list, lex->value_list,
                            lex->duplicates,
                            &select_lex->where, true, false, false))
-    return(true);
+    return true;
 
   /*
     exclude first table from leaf tables list, because it belong to
@@ -1065,7 +1054,7 @@ bool insert_select_prepare(Session *session)
   lex->leaf_tables_insert= select_lex->leaf_tables;
   /* skip all leaf tables belonged to view where we are insert */
   select_lex->leaf_tables= select_lex->leaf_tables->next_leaf;
-  return(false);
+  return false;
 }
 
 
@@ -1171,7 +1160,7 @@ select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
 
   session->lex().current_select= lex_current_select_save;
   if (res)
-    return(1);
+    return 1;
   /*
     if it is INSERT into join view then check_insert_fields already found
     real table for insert
@@ -1219,7 +1208,7 @@ select_insert::prepare(List<Item> &values, Select_Lex_Unit *u)
   table->mark_columns_needed_for_insert();
 
 
-  return(res);
+  return res;
 }
 
 
@@ -1244,7 +1233,7 @@ int select_insert::prepare2(void)
   if (session->lex().current_select->options & OPTION_BUFFER_RESULT)
     table->cursor->ha_start_bulk_insert((ha_rows) 0);
 
-  return(0);
+  return 0;
 }
 
 
@@ -1490,7 +1479,7 @@ static Table *create_table_from_items(Session *session, HA_CREATE_INFO *create_i
                                       List<Item> *items,
                                       bool is_if_not_exists,
                                       DrizzleLock **lock,
-				      identifier::Table::const_reference identifier)
+				      const identifier::Table& identifier)
 {
   TableShare share(message::Table::INTERNAL);
   uint32_t select_field_count= items->size();
@@ -1596,7 +1585,7 @@ static Table *create_table_from_items(Session *session, HA_CREATE_INFO *create_i
       if (not identifier.isTmp())
       {
         /* CREATE TABLE... has found that the table already exists for insert and is adapting to use it */
-        boost::mutex::scoped_lock scopedLock(table::Cache::singleton().mutex());
+        boost::mutex::scoped_lock scopedLock(table::Cache::mutex());
 
         if (create_table->table)
         {
@@ -1627,7 +1616,7 @@ static Table *create_table_from_items(Session *session, HA_CREATE_INFO *create_i
             it preparable for open. But let us do close_temporary_table() here
             just in case.
           */
-          session->drop_temporary_table(identifier);
+          session->open_tables.drop_temporary_table(identifier);
         }
       }
     }
@@ -1686,7 +1675,7 @@ select_create::prepare(List<Item> &values, Select_Lex_Unit *u)
     if (identifier.isTmp())
       m_plock= &m_lock;
     else
-      m_plock= &session->extra_lock;
+      m_plock= &session->open_tables.extra_lock;
 
     *m_plock= extra_lock;
   }
@@ -1724,11 +1713,11 @@ select_create::prepare(List<Item> &values, Select_Lex_Unit *u)
   table->cursor->ha_start_bulk_insert((ha_rows) 0);
   session->setAbortOnWarning(not info.ignore);
   if (check_that_all_fields_are_given_values(session, table, table_list))
-    return(1);
+    return 1;
 
   table->mark_columns_needed_for_insert();
   table->cursor->extra(HA_EXTRA_WRITE_CACHE);
-  return(0);
+  return 0;
 }
 
 void select_create::store_values(List<Item> &values)
@@ -1768,8 +1757,7 @@ bool select_create::send_eof()
     */
     if (!table->getShare()->getType())
     {
-      TransactionServices &transaction_services= TransactionServices::singleton();
-      transaction_services.autocommitOrRollback(*session, 0);
+      TransactionServices::autocommitOrRollback(*session, 0);
       (void) session->endActiveTransaction();
     }
 
