@@ -35,14 +35,17 @@
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/key.h>
 #include <drizzled/sql_lex.h>
+#include <drizzled/diagnostics_area.h>
+#include <drizzled/util/test.h>
+#include <drizzled/statistics_variables.h>
+#include <drizzled/session/transactions.h>
 
 #include <boost/dynamic_bitset.hpp>
 #include <list>
 
 using namespace std;
 
-namespace drizzled
-{
+namespace drizzled {
 
 /**
   Re-read record if more columns are needed for error message.
@@ -248,7 +251,7 @@ int update_query(Session *session, TableList *table_list,
      * Resetting the Diagnostic area to prevent
      * lp bug# 439719
      */
-    session->main_da.reset_diagnostics_area();
+    session->main_da().reset_diagnostics_area();
     free_underlaid_joins(session, select_lex);
     if (error || session->is_error())
     {
@@ -319,15 +322,11 @@ int update_query(Session *session, TableList *table_list,
       ha_rows examined_rows;
       FileSort filesort(*session);
 
-      table->sort.io_cache= new internal::IO_CACHE;
+      table->sort.io_cache= new internal::io_cache_st;
+      sortorder=make_unireg_sortorder(order, &length, NULL);
 
-      if (!(sortorder=make_unireg_sortorder(order, &length, NULL)) ||
-	  (table->sort.found_records= filesort.run(table, sortorder, length,
-						   select, limit, 1,
-						   examined_rows)) == HA_POS_ERROR)
-      {
-	goto err;
-      }
+      if ((table->sort.found_records= filesort.run(table, sortorder, length, select, limit, 1, examined_rows)) == HA_POS_ERROR)
+        goto err;
       /*
 	Filesort has already found and selected the rows we want to update,
 	so we don't need the where clause
@@ -342,7 +341,7 @@ int update_query(Session *session, TableList *table_list,
 	update these in a separate loop based on the pointer.
       */
 
-      internal::IO_CACHE tempfile;
+      internal::io_cache_st tempfile;
       if (tempfile.open_cached_file(drizzle_tmpdir.c_str(),TEMP_PREFIX, DISK_BUFFER_SIZE, MYF(MY_WME)))
       {
 	goto err;
@@ -386,8 +385,7 @@ int update_query(Session *session, TableList *table_list,
 	    continue;  /* repeat the read of the same row if it still exists */
 
 	  table->cursor->position(table->getInsertRecord());
-	  if (my_b_write(&tempfile,table->cursor->ref,
-			 table->cursor->ref_length))
+	  if (tempfile.write(table->cursor->ref, table->cursor->ref_length))
 	  {
 	    error=1;
 	    break;
@@ -577,7 +575,7 @@ int update_query(Session *session, TableList *table_list,
      * Resetting the Diagnostic area to prevent
      * lp bug# 439719
      */
-    session->main_da.reset_diagnostics_area();
+    session->main_da().reset_diagnostics_area();
     session->my_ok((ulong) session->rowCount(), found, id, buff);
     session->status_var.updated_row_count+= session->rowCount();
   }
@@ -626,25 +624,18 @@ bool prepare_update(Session *session, TableList *table_list,
 
   session->lex().allow_sum_func= 0;
 
-  if (setup_tables_and_check_access(session, &select_lex->context,
-                                    &select_lex->top_join_list,
-                                    table_list,
-                                    &select_lex->leaf_tables,
-                                    false) ||
-      session->setup_conds(table_list, conds) ||
-      select_lex->setup_ref_array(session, order_num) ||
-      setup_order(session, select_lex->ref_pointer_array,
-		  table_list, all_fields, all_fields, order))
+  if (setup_tables_and_check_access(session, &select_lex->context, &select_lex->top_join_list, table_list, &select_lex->leaf_tables, false) ||
+      session->setup_conds(table_list, conds))
+      return true;
+  select_lex->setup_ref_array(session, order_num);
+  if (setup_order(session, select_lex->ref_pointer_array, table_list, all_fields, all_fields, order))
     return true;
 
   /* Check that we are not using table that we are updating in a sub select */
+  if (unique_table(table_list, table_list->next_global))
   {
-    TableList *duplicate;
-    if ((duplicate= unique_table(table_list, table_list->next_global)))
-    {
-      my_error(ER_UPDATE_TABLE_USED, MYF(0), table_list->getTableName());
-      return true;
-    }
+    my_error(ER_UPDATE_TABLE_USED, MYF(0), table_list->getTableName());
+    return true;
   }
 
   return false;
