@@ -20,14 +20,11 @@
 
 #pragma once
 
+#include <drizzled/sql_lex.h>
 #include <drizzled/statement.h>
 
-namespace drizzled
-{
-class Session;
-
-namespace statement
-{
+namespace drizzled {
+namespace statement {
 
 class Flush : public Statement
 {
