@@ -22,6 +22,8 @@
 
 #include <drizzled/visibility.h>
 
+#define call_backtrace() drizzled::util::custom_backtrace(__FILE__, __LINE__, __func__)
+
 namespace drizzled
 {
 
@@ -29,7 +31,7 @@ namespace util
 {
 
 DRIZZLED_API
-void custom_backtrace(void);
+void custom_backtrace(const char *file, int line, const char *func);
 
 } /* namespace util */
 } /* namespace drizzled */
