@@ -42,9 +42,6 @@
  * @brief Defines, typedefs, enums, and macros
  */
 
-#include <libdrizzle-1.0/return.h>
-#include <libdrizzle-1.0/verbose.h>
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -93,6 +90,62 @@ extern "C" {
 #define DRIZZLE_DEFAULT_SOCKET_RECV_SIZE 32768
 #define DRIZZLE_MYSQL_PASSWORD_HASH      41
 
+/**
+ * Return codes.
+ */
+enum drizzle_return_t
+{
+  DRIZZLE_RETURN_OK,
+  DRIZZLE_RETURN_IO_WAIT,
+  DRIZZLE_RETURN_PAUSE,
+  DRIZZLE_RETURN_ROW_BREAK,
+  DRIZZLE_RETURN_MEMORY,
+  DRIZZLE_RETURN_ERRNO,
+  DRIZZLE_RETURN_INTERNAL_ERROR,
+  DRIZZLE_RETURN_GETADDRINFO,
+  DRIZZLE_RETURN_NOT_READY,
+  DRIZZLE_RETURN_BAD_PACKET_NUMBER,
+  DRIZZLE_RETURN_BAD_HANDSHAKE_PACKET,
+  DRIZZLE_RETURN_BAD_PACKET,
+  DRIZZLE_RETURN_PROTOCOL_NOT_SUPPORTED,
+  DRIZZLE_RETURN_UNEXPECTED_DATA,
+  DRIZZLE_RETURN_NO_SCRAMBLE,
+  DRIZZLE_RETURN_AUTH_FAILED,
+  DRIZZLE_RETURN_NULL_SIZE,
+  DRIZZLE_RETURN_ERROR_CODE,
+  DRIZZLE_RETURN_TOO_MANY_COLUMNS,
+  DRIZZLE_RETURN_ROW_END,
+  DRIZZLE_RETURN_LOST_CONNECTION,
+  DRIZZLE_RETURN_COULD_NOT_CONNECT,
+  DRIZZLE_RETURN_NO_ACTIVE_CONNECTIONS,
+  DRIZZLE_RETURN_HANDSHAKE_FAILED,
+  DRIZZLE_RETURN_TIMEOUT,
+  DRIZZLE_RETURN_INVALID_ARGUMENT,
+  DRIZZLE_RETURN_MAX /* Always add new codes to the end before this one. */
+};
+
+#ifndef __cplusplus
+typedef enum drizzle_return_t drizzle_return_t;
+#endif
+
+/**
+ * Verbosity levels.
+ */
+enum drizzle_verbose_t
+{
+  DRIZZLE_VERBOSE_NEVER,
+  DRIZZLE_VERBOSE_FATAL,
+  DRIZZLE_VERBOSE_ERROR,
+  DRIZZLE_VERBOSE_INFO,
+  DRIZZLE_VERBOSE_DEBUG,
+  DRIZZLE_VERBOSE_CRAZY,
+  DRIZZLE_VERBOSE_MAX
+};
+
+#ifndef __cplusplus
+typedef enum drizzle_verbose_t drizzle_verbose_t;
+#endif
+
 /** @} */
 
 /**
@@ -444,12 +497,6 @@ enum drizzle_column_flags_t
   DRIZZLE_COLUMN_FLAGS_RENAMED=          (1 << 21)
 };
 
-typedef enum
-{
-  DRIZZLE_SSL_STATE_NONE= 0,
-  DRIZZLE_SSL_STATE_HANDSHAKE_COMPLETE
-} drizzle_ssl_state_t;
-
 #ifndef __cplusplus
 typedef enum drizzle_column_flags_t drizzle_column_flags_t;
 #endif
