@@ -58,86 +58,6 @@
  */
 static drizzle_return_t _con_setsockopt(drizzle_con_st *con);
 
-static bool connect_poll(drizzle_con_st *con)
-{
-  struct pollfd fds[1];
-  fds[0].fd= con->fd;
-  fds[0].events= POLLOUT;
-
-  size_t loop_max= 5;
-  while (--loop_max) // Should only loop on cases of ERESTART or EINTR
-  {
-    int error= poll(fds, 1, con->drizzle->timeout);
-    switch (error)
-    {
-    case 1:
-      {
-        int err;
-        socklen_t len= sizeof (err);
-        // We replace errno with err if getsockopt() passes, but err has been
-        // set.
-        if (getsockopt(con->fd, SOL_SOCKET, SO_ERROR, &err, &len) == 0)
-        {
-          // We check the value to see what happened wth the socket.
-          if (err == 0)
-          {
-            return true;
-          }
-          errno= err;
-        }
-
-        // "getsockopt() failed"
-        return false;
-      }
-
-    case 0:
-      {
-        // "timeout occurred while trying to connect"
-        return false;
-      }
-
-    default: // A real error occurred and we need to completely bail
-      switch (get_socket_errno())
-      {
-#ifdef TARGET_OS_LINUX
-      case ERESTART:
-#endif
-      case EINTR:
-        continue;
-
-      case EFAULT:
-      case ENOMEM:
-        // "poll() failure"
-        return false;
-
-      case EINVAL:
-        // "RLIMIT_NOFILE exceeded, or if OSX the timeout value was invalid"
-        return false;
-
-      default: // This should not happen
-        if (fds[0].revents & POLLERR)
-        {
-          int err;
-          socklen_t len= sizeof (err);
-          (void)getsockopt(con->fd, SOL_SOCKET, SO_ERROR, &err, &len);
-          errno= err;
-        }
-        else
-        {
-          errno= get_socket_errno();
-        }
-
-        //"socket error occurred");
-        return false;
-      }
-    }
-  }
-
-  // This should only be possible from ERESTART or EINTR; 
-  // "connection failed (error should be from either ERESTART or EINTR"
-  return false;
-}
-
 /** @} */
 
 /*
@@ -780,17 +700,13 @@ drizzle_result_st *drizzle_con_command_write(drizzle_con_st *con,
 
     *ret_ptr= drizzle_con_connect(con);
     if (*ret_ptr != DRIZZLE_RETURN_OK)
-    {
       return result;
-    }
   }
 
   if (drizzle_state_none(con))
   {
     if (con->options & (DRIZZLE_CON_RAW_PACKET | DRIZZLE_CON_NO_RESULT_READ))
-    {
       con->result= NULL;
-    }
     else
     {
       for (old_result= con->result_list; old_result != NULL; old_result= old_result->next)
@@ -827,9 +743,7 @@ drizzle_result_st *drizzle_con_command_write(drizzle_con_st *con,
 
   *ret_ptr= drizzle_state_loop(con);
   if (*ret_ptr == DRIZZLE_RETURN_PAUSE)
-  {
     *ret_ptr= DRIZZLE_RETURN_OK;
-  }
   else if (*ret_ptr != DRIZZLE_RETURN_OK &&
            *ret_ptr != DRIZZLE_RETURN_IO_WAIT &&
            *ret_ptr != DRIZZLE_RETURN_ERROR_CODE)
@@ -1148,7 +1062,7 @@ void drizzle_con_reset_addrinfo(drizzle_con_st *con)
     break;
 
   case DRIZZLE_CON_SOCKET_UDS:
-    con->socket.uds.path_buffer[0]= 0;
+    con->socket.uds.addrinfo.ai_addr= NULL;
     break;
 
   default:
@@ -1236,6 +1150,7 @@ drizzle_return_t drizzle_state_addrinfo(drizzle_con_st *con)
     break;
 
   case DRIZZLE_CON_SOCKET_UDS:
+    con->addrinfo_next= &(con->socket.uds.addrinfo);
     break;
 
   default:
@@ -1264,153 +1179,102 @@ drizzle_return_t drizzle_state_connect(drizzle_con_st *con)
     con->fd= -1;
   }
 
-  if (con->socket_type == DRIZZLE_CON_SOCKET_UDS)
+  if (con->addrinfo_next == NULL)
   {
-#ifndef WIN32
-    if ((con->fd= socket(AF_UNIX, SOCK_STREAM, 0)) < 0)
-    {
-      con->drizzle->last_errno= errno;
-      return DRIZZLE_RETURN_COULD_NOT_CONNECT;
-    }
-
-    struct sockaddr_un servAddr;
-
-    memset(&servAddr, 0, sizeof (struct sockaddr_un));
-    servAddr.sun_family= AF_UNIX;
-    strncpy(servAddr.sun_path, con->socket.uds.path_buffer, sizeof(servAddr.sun_path)); /* Copy filename */
-
-    do {
-      if (connect(con->fd, (struct sockaddr *)&servAddr, sizeof(servAddr)) < 0)
-      {
-        switch (errno)
-        {
-        case EINPROGRESS:
-        case EALREADY:
-        case EINTR:
-          continue;
-
-        case EISCONN: /* We were spinning waiting on connect */
-          {
-            break;
-          }
-
-        default:
-          con->drizzle->last_errno= errno;
-          return DRIZZLE_RETURN_COULD_NOT_CONNECT;
-        }
-      }
-    } while (0);
-
-    return DRIZZLE_RETURN_OK;
-#else
+    drizzle_set_error(con->drizzle, __func__, "could not connect");
+    drizzle_state_reset(con);
     return DRIZZLE_RETURN_COULD_NOT_CONNECT;
-#endif
   }
-  else
+
+  con->fd= socket(con->addrinfo_next->ai_family,
+                  con->addrinfo_next->ai_socktype,
+                  con->addrinfo_next->ai_protocol);
+  if (con->fd == -1)
   {
-    if (con->addrinfo_next == NULL)
-    {
-      drizzle_set_error(con->drizzle, __func__, "could not connect");
-      drizzle_state_reset(con);
-      return DRIZZLE_RETURN_COULD_NOT_CONNECT;
-    }
+    drizzle_set_error(con->drizzle, __func__, "socket:%s", strerror(errno));
+    con->drizzle->last_errno= errno;
+    return DRIZZLE_RETURN_COULD_NOT_CONNECT;
+  }
 
-    con->fd= socket(con->addrinfo_next->ai_family,
-                    con->addrinfo_next->ai_socktype,
-                    con->addrinfo_next->ai_protocol);
-    if (con->fd == -1)
-    {
-      drizzle_set_error(con->drizzle, __func__, "socket:%s", strerror(errno));
-      con->drizzle->last_errno= errno;
-      return DRIZZLE_RETURN_COULD_NOT_CONNECT;
-    }
+  dret= _con_setsockopt(con);
+  if (dret != DRIZZLE_RETURN_OK)
+  {
+    con->drizzle->last_errno= errno;
+    return DRIZZLE_RETURN_COULD_NOT_CONNECT;
+  }
 
-    dret= _con_setsockopt(con);
-    if (dret != DRIZZLE_RETURN_OK)
-    {
-      con->drizzle->last_errno= errno;
-      return DRIZZLE_RETURN_COULD_NOT_CONNECT;
-    }
-
-    while (1)
-    {
-      ret= connect(con->fd, con->addrinfo_next->ai_addr,
-                   con->addrinfo_next->ai_addrlen);
+  while (1)
+  {
+    ret= connect(con->fd, con->addrinfo_next->ai_addr,
+                 con->addrinfo_next->ai_addrlen);
 
 #ifdef _WIN32
-      errno = WSAGetLastError();
-      switch(errno) {
-      case WSAEINVAL:
-      case WSAEALREADY:
-      case WSAEWOULDBLOCK:
-        errno= EINPROGRESS;
-        break;
-      case WSAECONNREFUSED:
-        errno= ECONNREFUSED;
-        break;
-      case WSAENETUNREACH:
-        errno= ENETUNREACH;
-        break;
-      case WSAETIMEDOUT:
-        errno= ETIMEDOUT;
-        break;
-      case WSAECONNRESET:
-        errno= ECONNRESET;
-        break;
-      case WSAEADDRINUSE:
-        errno= EADDRINUSE;
-        break;
-      case WSAEOPNOTSUPP:
-        errno= EOPNOTSUPP;
-        break;
-      case WSAENOPROTOOPT:
-        errno= ENOPROTOOPT;
-        break;
-      default:
-        break;
-      }
+    errno = WSAGetLastError();
+    switch(errno) {
+    case WSAEINVAL:
+    case WSAEALREADY:
+    case WSAEWOULDBLOCK:
+      errno= EINPROGRESS;
+      break;
+    case WSAECONNREFUSED:
+      errno= ECONNREFUSED;
+      break;
+    case WSAENETUNREACH:
+      errno= ENETUNREACH;
+      break;
+    case WSAETIMEDOUT:
+      errno= ETIMEDOUT;
+      break;
+    case WSAECONNRESET:
+      errno= ECONNRESET;
+      break;
+    case WSAEADDRINUSE:
+      errno= EADDRINUSE;
+      break;
+    case WSAEOPNOTSUPP:
+      errno= EOPNOTSUPP;
+      break;
+    case WSAENOPROTOOPT:
+      errno= ENOPROTOOPT;
+      break;
+    default:
+      break;
+    }
 #endif /* _WIN32 */
+	
+    drizzle_log_crazy(con->drizzle, "connect return=%d errno=%s", ret, strerror(errno));
 
-      drizzle_log_crazy(con->drizzle, "connect return=%d errno=%s", ret, strerror(errno));
-
-      if (ret == 0)
-      {
-        con->addrinfo_next= NULL;
-        break;
-      }
-
-      if (errno == EAGAIN || errno == EINTR)
-      {
-        continue;
-      }
-
-      if (errno == EINPROGRESS)
-      {
-        if (connect_poll(con))
-        {
-          drizzle_state_pop(con);
-          return DRIZZLE_RETURN_OK;
-        }
-      }
-      else if (errno == ECONNREFUSED || errno == ENETUNREACH || errno == ETIMEDOUT)
-      {
-        con->addrinfo_next= con->addrinfo_next->ai_next;
-        return DRIZZLE_RETURN_OK;
-      }
-
-      drizzle_set_error(con->drizzle, __func__, "connect:%s", strerror(errno));
-      con->drizzle->last_errno= errno;
-      return DRIZZLE_RETURN_COULD_NOT_CONNECT;
-    }
-
-    if (con->ssl)
+    if (ret == 0)
     {
-      SSL_set_fd(con->ssl, con->fd);
+      con->addrinfo_next= NULL;
+      break;
     }
 
-    drizzle_state_pop(con);
+    if (errno == EAGAIN || errno == EINTR)
+    {
+      continue;
+    }
+
+    if (errno == EINPROGRESS)
+    {
+      drizzle_state_pop(con);
+      drizzle_state_push(con, drizzle_state_connecting);
+      return DRIZZLE_RETURN_OK;
+    }
+
+    if (errno == ECONNREFUSED || errno == ENETUNREACH || errno == ETIMEDOUT)
+    {
+      con->addrinfo_next= con->addrinfo_next->ai_next;
+      return DRIZZLE_RETURN_OK;
+    }
+
+    drizzle_set_error(con->drizzle, __func__, "connect:%s", strerror(errno));
+    con->drizzle->last_errno= errno;
+    return DRIZZLE_RETURN_COULD_NOT_CONNECT;
   }
 
+  drizzle_state_pop(con);
+
   return DRIZZLE_RETURN_OK;
 }
 
@@ -1427,10 +1291,11 @@ drizzle_return_t drizzle_state_connecting(drizzle_con_st *con)
 
   while (1)
   {
-    int error= 0;
+    int error;
     if (con->revents & POLLOUT)
     {
       drizzle_state_pop(con);
+      return DRIZZLE_RETURN_OK;
       socklen_t error_length= sizeof(error);
       int getsockopt_error;
       if ((getsockopt_error= getsockopt(con->fd, SOL_SOCKET, SO_ERROR, (void*)&error, &error_length)) < 1)
@@ -1514,11 +1379,7 @@ drizzle_return_t drizzle_state_read(drizzle_con_st *con)
   {
     size_t available_buffer= (size_t)DRIZZLE_MAX_BUFFER_SIZE -
         ((size_t)(con->buffer_ptr - con->buffer) + con->buffer_size);
-
-    if (con->ssl_state == DRIZZLE_SSL_STATE_HANDSHAKE_COMPLETE)
-      read_size= SSL_read(con->ssl, (char*)con->buffer_ptr + con->buffer_size, available_buffer);
-    else
-      read_size = recv(con->fd, (char *)con->buffer_ptr + con->buffer_size,
+    read_size = recv(con->fd, (char *)con->buffer_ptr + con->buffer_size,
                      available_buffer, 0);
 #ifdef _WIN32
     errno = WSAGetLastError();
@@ -1556,15 +1417,13 @@ drizzle_return_t drizzle_state_read(drizzle_con_st *con)
       break;
     }
 #endif /* _WIN32 */	
-    drizzle_log_crazy(con->drizzle, "read fd=%d return=%zd ssl= %d errno=%s",
-                      con->fd, read_size, 
-                      (con->ssl_state == DRIZZLE_SSL_STATE_HANDSHAKE_COMPLETE) ? 1 : 0,
-                      strerror(errno));
+    drizzle_log_crazy(con->drizzle, "read fd=%d return=%zd errno=%s", con->fd,
+                      read_size, strerror(errno));
 
     if (read_size == 0)
     {
-      drizzle_set_error(con->drizzle, __func__,
-                        "%s:%d lost connection to server (EOF)", __FILE__, __LINE__);
+      drizzle_set_error(con->drizzle, "drizzle_state_read",
+                        "lost connection to server (EOF)");
       return DRIZZLE_RETURN_LOST_CONNECTION;
     }
     else if (read_size == -1)
@@ -1601,8 +1460,7 @@ drizzle_return_t drizzle_state_read(drizzle_con_st *con)
       else if (errno == EPIPE || errno == ECONNRESET)
       {
         drizzle_set_error(con->drizzle, __func__,
-                          "%s:%d lost connection to server (%s)",
-                          __FILE__, __LINE__, strerror(errno));
+                          "lost connection to server (%s)", strerror(errno));
         return DRIZZLE_RETURN_LOST_CONNECTION;
       }
 
@@ -1639,10 +1497,8 @@ drizzle_return_t drizzle_state_write(drizzle_con_st *con)
 
   while (con->buffer_size != 0)
   {
-    if (con->ssl_state == DRIZZLE_SSL_STATE_HANDSHAKE_COMPLETE)
-      write_size= SSL_write(con->ssl, con->buffer_ptr, con->buffer_size);
-    else
-      write_size = send(con->fd,(char *) con->buffer_ptr, con->buffer_size, 0);
+  
+    write_size = send(con->fd,(char *) con->buffer_ptr, con->buffer_size, 0);
 
 #ifdef _WIN32
     errno = WSAGetLastError();
@@ -1681,33 +1537,28 @@ drizzle_return_t drizzle_state_write(drizzle_con_st *con)
     }
 #endif /* _WIN32 */	
 
-    drizzle_log_crazy(con->drizzle, "write fd=%d return=%zd ssl=%d errno=%s",
-                      con->fd, write_size,
-                      (con->ssl_state == DRIZZLE_SSL_STATE_HANDSHAKE_COMPLETE) ? 1 : 0,
-                      strerror(errno));
+    drizzle_log_crazy(con->drizzle, "write fd=%d return=%zd errno=%s", con->fd,
+                      write_size, strerror(errno));
 
     if (write_size == 0)
-    { }
+    {
+      drizzle_set_error(con->drizzle, __func__, "lost connection to server (EOF)");
+      return DRIZZLE_RETURN_LOST_CONNECTION;
+    }
     else if (write_size == -1)
     {
       if (errno == EAGAIN)
       {
         ret= drizzle_con_set_events(con, POLLOUT);
         if (ret != DRIZZLE_RETURN_OK)
-        {
           return ret;
-        }
 
         if (con->drizzle->options & DRIZZLE_NON_BLOCKING)
-        {
           return DRIZZLE_RETURN_IO_WAIT;
-        }
 
         ret= drizzle_con_wait(con->drizzle);
         if (ret != DRIZZLE_RETURN_OK)
-        {
           return ret;
-        }
 
         continue;
       }
@@ -1717,8 +1568,7 @@ drizzle_return_t drizzle_state_write(drizzle_con_st *con)
       }
       else if (errno == EPIPE || errno == ECONNRESET)
       {
-        drizzle_set_error(con->drizzle, __func__, "%s:%d lost connection to server (%s)", 
-                          __FILE__, __LINE__, strerror(errno));
+        drizzle_set_error(con->drizzle, __func__, "lost connection to server (%s)", strerror(errno));
         return DRIZZLE_RETURN_LOST_CONNECTION;
       }
 
@@ -1958,21 +1808,18 @@ static drizzle_return_t _con_setsockopt(drizzle_con_st *con)
     ioctlsocket(con->fd, FIONBIO, &asyncmode);
   }
 #else
-  if (!con->ssl)
+  ret= fcntl(con->fd, F_GETFL, 0);
+  if (ret == -1)
   {
-    ret= fcntl(con->fd, F_GETFL, 0);
-    if (ret == -1)
-    {
-      drizzle_set_error(con->drizzle, __func__, "fcntl:F_GETFL:%s", strerror(errno));
-      return DRIZZLE_RETURN_ERRNO;
-    }
+    drizzle_set_error(con->drizzle, __func__, "fcntl:F_GETFL:%s", strerror(errno));
+    return DRIZZLE_RETURN_ERRNO;
+  }
 
-    ret= fcntl(con->fd, F_SETFL, ret | O_NONBLOCK);
-    if (ret == -1)
-    {
-      drizzle_set_error(con->drizzle, __func__, "fcntl:F_SETFL:%s", strerror(errno));
-      return DRIZZLE_RETURN_ERRNO;
-    }
+  ret= fcntl(con->fd, F_SETFL, ret | O_NONBLOCK);
+  if (ret == -1)
+  {
+    drizzle_set_error(con->drizzle, __func__, "fcntl:F_SETFL:%s", strerror(errno));
+    return DRIZZLE_RETURN_ERRNO;
   }
 #endif
 
