@@ -24,14 +24,14 @@
 
 #include <config.h>
 
+#include <drizzled/identifier.h>
+#include <drizzled/plugin/authentication.h>
+
 #include <security/pam_appl.h>
 #if !defined(__sun) && !defined(__FreeBSD__)
 #include <security/pam_misc.h>
 #endif
 
-#include <drizzled/identifier.h>
-#include <drizzled/plugin/authentication.h>
-
 using namespace drizzled;
 
 typedef struct {
@@ -67,8 +67,6 @@ int auth_pam_talker(int num_msg,
 
   /* allocate memory to store response */
   response= (struct pam_response*)malloc(num_msg * sizeof(struct pam_response));
-  if(!response)
-    return PAM_CONV_ERR;
 
   /* copy values */
   for(int x= 0; x < num_msg; x++)
@@ -88,8 +86,7 @@ int auth_pam_talker(int num_msg,
       response[x].resp = strdup(userinfo->password);
       break;
     default:
-      if(response)
-        free(response);
+      free(response);
       return PAM_CONV_ERR;
     }
   }
