@@ -40,7 +40,6 @@
 #include <plugin/json_server/json/value.h>
 #include <plugin/json_server/json/writer.h>
 
-#include <cstdio>
 #include <cassert>
 #include <cstring>
 #include <iostream>
@@ -309,7 +308,6 @@ Value::Value( ValueType type_arg )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    switch ( type_arg )
    {
@@ -353,7 +351,6 @@ Value::Value( Int value )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    value_.int_ = value;
 }
@@ -365,7 +362,6 @@ Value::Value( UInt value )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    value_.uint_ = value;
 }
@@ -376,7 +372,6 @@ Value::Value( double value )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    value_.real_ = value;
 }
@@ -388,7 +383,6 @@ Value::Value( const char *value )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    value_.string_ = valueAllocator()->duplicateStringValue( value );
 }
@@ -402,7 +396,6 @@ Value::Value( const char *beginValue,
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    value_.string_ = valueAllocator()->duplicateStringValue( beginValue, 
                                                             UInt(endValue - beginValue) );
@@ -416,7 +409,6 @@ Value::Value( const std::string &value )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    value_.string_ = valueAllocator()->duplicateStringValue( value.c_str(), 
                                                             (unsigned int)value.length() );
@@ -430,7 +422,6 @@ Value::Value( const StaticString &value )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    value_.string_ = const_cast<char *>( value.c_str() );
 }
@@ -444,7 +435,6 @@ Value::Value( const CppTL::ConstString &value )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    value_.string_ = valueAllocator()->duplicateStringValue( value, value.length() );
 }
@@ -456,7 +446,6 @@ Value::Value( bool value )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    value_.bool_ = value;
 }
@@ -468,7 +457,6 @@ Value::Value( const Value &other )
 # ifdef JSON_VALUE_USE_INTERNAL_MAP
    , itemIsUsed_( 0 )
 #endif
-   , value_as_string_( 0 )
 {
    switch ( type_ )
    {
@@ -516,6 +504,7 @@ Value::Value( const Value &other )
    }
 }
 
+
 Value::~Value()
 {
    switch ( type_ )
@@ -525,9 +514,7 @@ Value::~Value()
    case uintValue:
    case realValue:
    case booleanValue:
-       if ( value_as_string_ )
-           valueAllocator()->releaseStringValue( value_as_string_ );
-       break;
+      break;
    case stringValue:
       if ( allocated_ )
          valueAllocator()->releaseStringValue( value_.string_ );
@@ -728,12 +715,9 @@ Value::asCString() const
    return value_.string_;
 }
 
-/**
- * If type_ is not stringValue, we will here convert other values to value_as_string_ field,
- * then return it.
- */
+
 std::string 
-Value::asString()
+Value::asString() const
 {
    switch ( type_ )
    {
@@ -744,29 +728,8 @@ Value::asString()
    case booleanValue:
       return value_.bool_ ? "true" : "false";
    case intValue:
-      if(!value_as_string_)
-      {
-          char buf[64];
-          sprintf(buf, "%d", value_.int_);
-          value_as_string_ = valueAllocator()->duplicateStringValue( buf );
-      }
-      return value_as_string_;
    case uintValue:
-      if(!value_as_string_)
-      {
-          char buf[64];
-          sprintf(buf, "%d", value_.uint_);
-          value_as_string_ = valueAllocator()->duplicateStringValue( buf );
-      }
-      return value_as_string_;
    case realValue:
-      if(!value_as_string_)
-      {
-          char buf[256];
-          sprintf(buf, "%f", value_.real_);
-          value_as_string_ = valueAllocator()->duplicateStringValue( buf );
-      }
-      return value_as_string_;
    case arrayValue:
    case objectValue:
       JSON_ASSERT_MESSAGE( false, "Type is not convertible to string" );
