@@ -18,9 +18,11 @@
  */
 
 #include <config.h>
+#include <drizzled/plugin.h>
 #include <drizzled/plugin/logging.h>
 #include <drizzled/gettext.h>
 #include <drizzled/session.h>
+#include <drizzled/session/times.h>
 #include <drizzled/sql_parse.h>
 #include PCRE_HEADER
 #include <limits.h>
@@ -237,9 +239,9 @@ public:
       inside itself, so be more accurate, and so this doesnt have to
       keep calling current_utime, which can be slow.
     */
-    uint64_t t_mark= session->getCurrentTimestamp(false);
+    uint64_t t_mark= session->times.getCurrentTimestamp(false);
 
-    if (session->getElapsedTime() < (sysvar_logging_query_threshold_slow.get()))
+    if (session->times.getElapsedTime() < sysvar_logging_query_threshold_slow.get())
       return false;
 
     Session::QueryString query_string(session->getQueryString());
@@ -266,18 +268,16 @@ public:
     quotify(*query_string, qs);
 
     // to avoid trying to printf %s something that is potentially NULL
-    util::string::const_shared_ptr schema(session->schema());
-    const char *dbs= (schema and not schema->empty()) ? schema->c_str() : "";
-
+    util::string::ptr schema(session->schema());
     formatter % t_mark
               % session->thread_id
               % session->getQueryId()
-              % dbs
+              % (schema ? schema->c_str() : "")
               % qs
               % getCommandName(session->command)
-              % (t_mark - session->getConnectMicroseconds())
-              % session->getElapsedTime()
-              % (t_mark - session->utime_after_lock)
+              % (t_mark - session->times.getConnectMicroseconds())
+              % session->times.getElapsedTime()
+              % (t_mark - session->times.utime_after_lock)
               % session->sent_row_count
               % session->examined_row_count
               % session->tmp_table
@@ -297,10 +297,9 @@ public:
 
 static int logging_query_plugin_init(drizzled::module::Context &context)
 {
-
   const module::option_map &vm= context.getOptions();
 
-  if (vm.count("filename") > 0)
+  if (vm.count("filename"))
   {
     context.add(new Logging_query(vm["filename"].as<string>(),
                                   vm["pcre"].as<string>()));
