@@ -20,6 +20,10 @@
 #include <drizzled/field/varstring.h>
 #include <drizzled/plugin/daemon.h>
 #include <drizzled/plugin/storage_engine.h>
+#include <drizzled/util/test.h>
+#include <drizzled/session/table_messages.h>
+#include <drizzled/statistics_variables.h>
+#include <drizzled/system_variables.h>
 
 #include <boost/thread/mutex.hpp>
 
@@ -28,7 +32,6 @@
 
 #include <string>
 
-
 using namespace drizzled;
 using namespace std;
 
@@ -65,10 +68,16 @@ public:
     return new ha_heap(*this, table);
   }
 
-  const char **bas_ext() const {
+  const char **bas_ext() const 
+  {
     return ha_heap_exts;
   }
 
+  drizzled::message::Table::Index::IndexType default_index_type() const
+  {
+    return drizzled::message::Table::Index::HASH;
+  }
+
   int doCreateTable(Session &session,
                     Table &table_arg,
                     const identifier::Table &identifier,
@@ -104,12 +113,12 @@ public:
   bool doDoesTableExist(Session& session, const identifier::Table &identifier);
   void doGetTableIdentifiers(CachedDirectory &directory,
                              const identifier::Schema &schema_identifier,
-                             identifier::Table::vector &set_of_identifiers);
+                             identifier::table::vector &set_of_identifiers);
 };
 
 void HeapEngine::doGetTableIdentifiers(CachedDirectory&,
                                        const identifier::Schema&,
-                                       identifier::Table::vector&)
+                                       identifier::table::vector&)
 {
 }
 
@@ -219,7 +228,7 @@ int ha_heap::doOpen(const drizzled::identifier::Table &identifier, int mode, uin
     */
     key_stat_version= file->getShare()->key_stat_version - 1;
   }
-  return (file ? 0 : 1);
+  return file ? 0 : 1;
 }
 
 int ha_heap::close(void)
@@ -612,12 +621,12 @@ int ha_heap::enable_indexes(uint32_t mode)
    [2  non-unique indexes are disabled - NOT YET IMPLEMENTED]
 */
 
-int ha_heap::indexes_are_disabled(void)
+int ha_heap::indexes_are_disabled()
 {
   return heap_indexes_are_disabled(file);
 }
 
-void ha_heap::drop_table(const char *)
+void ha_heap::drop_table()
 {
   file->getShare()->delete_on_close= 1;
   close();
