@@ -25,6 +25,8 @@
 #include <drizzled/abort_exception.h>
 #include <drizzled/transaction_services.h>
 #include <drizzled/gettext.h>
+#include <drizzled/plugin.h>
+#include <drizzled/statistics_variables.h>
 
 #include <boost/thread.hpp>
 #include <boost/bind.hpp>
@@ -52,7 +54,7 @@ void MultiThreadScheduler::runSession(drizzled::session_id_t id)
   char stack_dummy;
   boost::this_thread::disable_interruption disable_by_default;
 
-  Session::shared_ptr session(session::Cache::singleton().find(id));
+  Session::shared_ptr session(session::Cache::find(id));
 
   try
   {
@@ -63,19 +65,9 @@ void MultiThreadScheduler::runSession(drizzled::session_id_t id)
       return;
     }
     session->pushInterrupt(&disable_by_default);
-
-    if (drizzled::internal::my_thread_init())
-    {
-      session->disconnect(drizzled::ER_OUT_OF_RESOURCES);
-      session->status_var.aborted_connects++;
-    }
-    else
-    {
-      boost::this_thread::at_thread_exit(&internal::my_thread_end);
-
-      session->thread_stack= (char*) &stack_dummy;
-      session->run();
-    }
+    drizzled::internal::my_thread_init();
+    session->thread_stack= (char*) &stack_dummy;
+    session->run();
 
     killSessionNow(session);
   }
@@ -86,7 +78,7 @@ void MultiThreadScheduler::runSession(drizzled::session_id_t id)
     cout << _("In File: ") << *::boost::get_error_info<boost::throw_file>(ex) << endl;
     cout << _("On Line: ") << *::boost::get_error_info<boost::throw_line>(ex) << endl;
 
-    TransactionServices::singleton().sendShutdownEvent(*session.get());
+    TransactionServices::sendShutdownEvent(*session.get());
   }
   // @todo remove hard spin by disconnection the session first from the
   // thread.
@@ -131,7 +123,7 @@ void MultiThreadScheduler::setStackSize()
 #endif
 }
 
-bool MultiThreadScheduler::addSession(Session::shared_ptr &session)
+bool MultiThreadScheduler::addSession(const Session::shared_ptr& session)
 {
   if (thread_count >= max_threads)
     return true;
@@ -165,7 +157,7 @@ bool MultiThreadScheduler::addSession(Session::shared_ptr &session)
 
 void MultiThreadScheduler::killSession(Session *session)
 {
-  boost_thread_shared_ptr thread(session->getThread());
+  thread_ptr thread(session->getThread());
 
   if (thread)
   {
@@ -173,7 +165,7 @@ void MultiThreadScheduler::killSession(Session *session)
   }
 }
 
-void MultiThreadScheduler::killSessionNow(Session::shared_ptr &session)
+void MultiThreadScheduler::killSessionNow(const Session::shared_ptr& session)
 {
   killSession(session.get());
 
@@ -186,7 +178,7 @@ void MultiThreadScheduler::killSessionNow(Session::shared_ptr &session)
 
 MultiThreadScheduler::~MultiThreadScheduler()
 {
-  boost::mutex::scoped_lock scopedLock(drizzled::session::Cache::singleton().mutex());
+  boost::mutex::scoped_lock scopedLock(drizzled::session::Cache::mutex());
   while (thread_count)
   {
     COND_thread_count.wait(scopedLock);
