@@ -33,9 +33,11 @@
 #include <drizzled/table.h>
 #include <drizzled/memory/multi_malloc.h>
 #include <drizzled/plugin/daemon.h>
-
+#include <drizzled/session/table_messages.h>
 #include <drizzled/plugin/storage_engine.h>
 #include <drizzled/key.h>
+#include <drizzled/statistics_variables.h>
+#include <drizzled/system_variables.h>
 
 #include <boost/algorithm/string.hpp>
 #include <boost/scoped_ptr.hpp>
@@ -58,22 +60,10 @@ static const string engine_name("MyISAM");
 boost::mutex THR_LOCK_myisam;
 
 static uint32_t myisam_key_cache_block_size= KEY_CACHE_BLOCK_SIZE;
-static uint32_t myisam_key_cache_size;
-static uint32_t myisam_key_cache_division_limit;
-static uint32_t myisam_key_cache_age_threshold;
 static uint64_t max_sort_file_size;
 typedef constrained_check<size_t, SIZE_MAX, 1024, 1024> sort_buffer_constraint;
 static sort_buffer_constraint sort_buffer_size;
 
-void st_mi_isam_share::setKeyCache()
-{
-  (void)init_key_cache(&key_cache,
-                       myisam_key_cache_block_size,
-                       myisam_key_cache_size,
-                       myisam_key_cache_division_limit, 
-                       myisam_key_cache_age_threshold);
-}
-
 /*****************************************************************************
 ** MyISAM tables
 *****************************************************************************/
@@ -86,9 +76,6 @@ static const char *ha_myisam_exts[] = {
 
 class MyisamEngine : public plugin::StorageEngine
 {
-  MyisamEngine();
-  MyisamEngine(const MyisamEngine&);
-  MyisamEngine& operator=(const MyisamEngine&);
 public:
   explicit MyisamEngine(string name_arg) :
     plugin::StorageEngine(name_arg,
@@ -146,7 +133,7 @@ public:
 
   void doGetTableIdentifiers(drizzled::CachedDirectory &directory,
                              const drizzled::identifier::Schema &schema_identifier,
-                             drizzled::identifier::Table::vector &set_of_identifiers);
+                             drizzled::identifier::table::vector &set_of_identifiers);
   bool validateCreateTableOption(const std::string &key, const std::string &state)
   {
     (void)state;
@@ -161,7 +148,7 @@ public:
 
 void MyisamEngine::doGetTableIdentifiers(drizzled::CachedDirectory&,
                                          const drizzled::identifier::Schema&,
-                                         drizzled::identifier::Table::vector&)
+                                         drizzled::identifier::table::vector&)
 {
 }
 
