@@ -28,6 +28,8 @@
 
 #include "policy.h"
 
+#include <fstream>
+
 namespace po= boost::program_options;
 
 using namespace std;
@@ -40,15 +42,12 @@ static int init(module::Context &context)
 {
   const module::option_map &vm= context.getOptions();
 
-  Policy *policy= new (nothrow) Policy(fs::path(vm["policy"].as<string>()));
-  if (policy == NULL or not policy->loadFile())
+  Policy *policy= new Policy(fs::path(vm["policy"].as<string>()));
+  if (not policy->loadFile())
   {
     errmsg_printf(error::ERROR, _("Could not load regex policy file: %s\n"),
                   (policy ? policy->getError().str().c_str() : _("Unknown")));
-    if (policy)
-    {
-      delete policy;
-    }
+    delete policy;
     return 1;
   }
 
@@ -197,7 +196,7 @@ bool Policy::restrictObject(const drizzled::identifier::User &user_ctx,
 }
 
 bool Policy::restrictSchema(const drizzled::identifier::User &user_ctx,
-                                   drizzled::identifier::Schema::const_reference schema)
+                                   const drizzled::identifier::Schema& schema)
 {
   return restrictObject(user_ctx, schema.getSchemaName(), schema_policies, &schema_check_cache);
 }
@@ -208,8 +207,8 @@ bool Policy::restrictProcess(const drizzled::identifier::User &user_ctx,
   return restrictObject(user_ctx, session_ctx.username(), process_policies, &process_check_cache);
 }
 
-bool Policy::restrictTable(drizzled::identifier::User::const_reference user_ctx,
-                             drizzled::identifier::Table::const_reference table)
+bool Policy::restrictTable(const drizzled::identifier::User& user_ctx,
+                             const drizzled::identifier::Table& table)
 {
   return restrictObject(user_ctx, table.getTableName(), table_policies, &table_check_cache);
 }
@@ -253,35 +252,23 @@ CheckItem::CheckItem(const std::string &user_in, const std::string &obj_in, Chec
 void CheckItem::setCachedResult(bool result)
 {
   // TODO: make the mutex per-cache
-  CheckMap *old_cache;
-  CheckMap *new_cache;
   boost::mutex::scoped_lock lock(check_cache_mutex, boost::defer_lock);
   lock.lock();
 
   // Copy the current one
-  if (*check_cache)
-  {
-    new_cache= new CheckMap(**check_cache);
-  }
-  else
-  {
-    new_cache= new CheckMap();
-  }
+  CheckMap* new_cache= *check_cache ? new CheckMap(**check_cache) : new CheckMap;
 
   // Update it
   (*new_cache)[key]= result;
   // Replace old
-  old_cache= *check_cache;
+  CheckMap* old_cache= *check_cache;
   *check_cache= new_cache;
 
   lock.unlock();
   has_cached_result= true;
   cached_result= result;
 
-  if (old_cache)
-  {
-    delete old_cache;
-  }
+  delete old_cache;
 }
 
 } /* namespace regex_policy */
