@@ -24,8 +24,7 @@
 
 #pragma once
 
-#include <iostream>
-#include <fstream>
+#include <iosfwd>
 
 #include <boost/regex.hpp>
 #include <boost/unordered_map.hpp>
@@ -36,8 +35,7 @@
 
 namespace fs= boost::filesystem;
 
-namespace regex_policy
-{
+namespace regex_policy {
 
 static const fs::path DEFAULT_POLICY_FILE= SYSCONFDIR "/drizzle.policy";
 
@@ -86,7 +84,7 @@ public:
   }
   bool userMatches(std::string &str);
   bool objectMatches(std::string &object_id);
-  bool isRestricted();
+  bool isRestricted() const;
   const std::string&getUser() const
   {
     return user;
@@ -138,9 +136,9 @@ inline bool PolicyItem::objectMatches(std::string &object_id)
   return boost::regex_match(object_id, object_re);
 }
 
-inline bool PolicyItem::isRestricted()
+inline bool PolicyItem::isRestricted() const
 {
-  return action == POLICY_DENY ? true : false;
+  return action == POLICY_DENY;
 }
 
 void clearPolicyItemList(PolicyItemList policies);
@@ -155,13 +153,13 @@ public:
   { }
 
   virtual bool restrictSchema(const drizzled::identifier::User &user_ctx,
-                              drizzled::identifier::Schema::const_reference schema);
+                              const drizzled::identifier::Schema& schema);
 
   virtual bool restrictProcess(const drizzled::identifier::User &user_ctx,
                                const drizzled::identifier::User &session_ctx);
 
-  virtual bool restrictTable(drizzled::identifier::User::const_reference user_ctx,
-                             drizzled::identifier::Table::const_reference table);
+  virtual bool restrictTable(const drizzled::identifier::User& user_ctx,
+                             const drizzled::identifier::Table& table);
 
   bool loadFile();
   std::stringstream &getError() { return error; }
