@@ -1,7 +1,7 @@
 /* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
  *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
  *
- *  Copyright (C) 2010 Sun Microsystems
+ *  Copyright (C) 2010 Sun Microsystems, Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,8 +18,7 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef PLUGIN_SCHEMA_DICTIONARY_TABLES_H
-#define PLUGIN_SCHEMA_DICTIONARY_TABLES_H
+#pragma once
 
 class TablesTool : public drizzled::plugin::TableFunction
 {
@@ -47,8 +46,6 @@ public:
 
     bool nextTable();
 
-    void pushType(drizzled::message::Table::Field::FieldType type);
-
     const std::string &table_name()
     {
       return table_message.name();
@@ -79,4 +76,3 @@ public:
 
 };
 
-#endif /* PLUGIN_SCHEMA_DICTIONARY_TABLES_H */
