@@ -25,6 +25,7 @@
 #include <plugin/slave/replication_schema.h>
 #include <drizzled/plugin/daemon.h>
 #include <boost/thread.hpp>
+#include <boost/unordered_map.hpp>
 
 namespace drizzled
 {
@@ -40,65 +41,88 @@ public:
 
   ReplicationSlave(const std::string &config)
     : drizzled::plugin::Daemon("Replication Slave"),
-      _config_file(config),
-      _initial_max_commit_id(0)
+      _config_file(config)
   {}
   
   ~ReplicationSlave()
   {
     _consumer_thread.interrupt();
-    _producer_thread.interrupt();
+
+    boost::unordered_map<uint32_t, Master *>::const_iterator it;
+
+    for (it= _masters.begin(); it != _masters.end(); ++it)
+    {
+      it->second->thread().interrupt();
+    }
   }
 
+  /** Gets called after all plugins are initialized */
   void startup(drizzled::Session &session);
 
-  /**
-   * Get the error message describing what went wrong during setup.
-   */
-  const std::string &getError() const
-  {
-    return _error;
-  }
-
-  /**
-   * Set the initial value for the slave's maximum commit ID.
-   *
-   * This value basically determines where to start retrieving events from
-   * the master. Normally this is computed automatically based on the
-   * contents of the queue and/or the last applied commit ID. This allows
-   * us to override those values and start from another point. E.g., new
-   * slave provisioning or skipping a trouble statement.
-   *
-   * @param[in] value The commit ID value.
-   */
-  void setMaxCommitId(uint64_t value)
-  {
-    /* must tell producer to set its cached value */
-    _producer.setCachedMaxCommitId(value);
-    /* setting this indicates that we should store it permanently */
-    _initial_max_commit_id= value;
-  }
-
 private:
+
+  /**
+   * Class representing a master server.
+   */
+  class Master
+  {
+  public:
+    Master(uint32_t id)
+    {
+      _producer.setMasterId(id);
+    }
+
+    QueueProducer &producer()
+    {
+      return _producer;
+    }
+  
+    boost::thread &thread()
+    {
+      return _producer_thread;
+    }
+
+    void start()
+    {
+      _producer_thread= boost::thread(&QueueProducer::run, &_producer);
+    }
+
+  private:
+    /** Manages a single master */
+    QueueProducer _producer;
+
+    /** I/O thread that will populate the work queue */
+    boost::thread _producer_thread;
+  };
+
+  /** Configuration file containing master info */
   std::string _config_file;
+
   std::string _error;
-
+  
+  /** Object to use with the consumer thread */
   QueueConsumer _consumer;
-  QueueProducer _producer;
 
-  /** Applier thread that will drain the work queue */
+  /**
+   * Applier thread that will drain the work queue.
+   * @todo Support more than one consumer thread.
+   */
   boost::thread _consumer_thread;
 
-  /** I/O thread that will populate the work queue */
-  boost::thread _producer_thread;
+  /** List of master objects, one per master */
+  boost::unordered_map<uint32_t, Master *> _masters;
 
-  uint64_t _initial_max_commit_id;
+  /** Convenience method to get object reference */
+  Master &master(size_t index)
+  {
+    return *(_masters[index]);
+  }
 
   /**
    * Initialize slave services with the given configuration file.
    *
-   * In case of an error during initialization, you can call the getError()
-   * method to get a string describing what went wrong.
+   * In case of an error during initialization, _error contains a
+   * string describing what went wrong.
    *
    * @retval true Success
    * @retval false Failure
