@@ -22,7 +22,7 @@
 
 #include <algorithm>
 
-#include <drizzled/charset_info.h>
+#include <drizzled/charset.h>
 #include <drizzled/function/str/strfunc.h>
 #include <drizzled/plugin/function.h>
 
