@@ -38,8 +38,8 @@ public:
   void errorHandler(drizzle_result_st *res,  drizzle_return_t ret, const char *when);
 
 private:
-  drizzle_st drizzle;
-  drizzle_con_st connection;
+  drizzle_st *drizzle;
+  drizzle_con_st *connection;
   std::string hostName;
   bool drizzleProtocol;
 };
