@@ -20,7 +20,7 @@
 
 #include <config.h>
 
-#include <drizzled/charset_info.h>
+#include <drizzled/charset.h>
 #include <drizzled/function/str/strfunc.h>
 #include <drizzled/item/func.h>
 #include <drizzled/plugin/function.h>
