@@ -1,5 +1,5 @@
 #! /usr/bin/env python
-# -*- mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+# -*- mode: python; indent-tabs-mode: nil; -*-
 # vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 #
 # Copyright (C) 2010 Patrick Crews
@@ -19,7 +19,7 @@
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 """ test_execution:
-    code related to the execution of est cases 
+    code related to the execution of test cases 
     
     We are provided access to a testManager with 
     mode-specific testCases.  We contact the executionManager
@@ -75,29 +75,28 @@ class testExecutor():
         self.current_test_output = None
         self.current_test_exec_time = 0 
          
-        if self.debug:
-            self.logging.debug_class(self)
+        self.logging.debug_class(self)
 
     def execute(self, start_and_exit):
         """ Execute a test case.  The details are *very* mode specific """
         self.status = 1 # we are running
         keep_running = 1
-        if self.verbose:
-            self.logging.verbose("Executor: %s beginning test execution..." %(self.name))
+        self.logging.verbose("Executor: %s beginning test execution..." %(self.name))
         while self.test_manager.has_tests() and keep_running == 1:
             self.get_testCase()
             for i in range(self.testcase_repeat_count):
-                self.handle_system_reqs()
-                self.handle_server_reqs()
-                self.handle_utility_reqs()
-                self.handle_start_and_exit(start_and_exit)
-                if self.current_test_status != 'fail':
-                    self.execute_testCase()
-                self.record_test_result()
-                if self.current_test_status == 'fail' and not self.execution_manager.force:
-                    self.logging.error("Failed test.  Use --force to execute beyond the first test failure")
-                    keep_running = 0
-                self.current_test_status = None # reset ourselves
+                if keep_running:
+                    self.handle_system_reqs()
+                    self.handle_server_reqs()
+                    self.handle_utility_reqs()
+                    self.handle_start_and_exit(start_and_exit)
+                    if self.current_test_status != 'fail':
+                        self.execute_testCase()
+                    self.record_test_result()
+                    if self.current_test_status == 'fail' and not self.execution_manager.force:
+                        self.logging.error("Failed test.  Use --force to execute beyond the first test failure")
+                        keep_running = 0
+                    self.current_test_status = None # reset ourselves
         self.status = 0
 
     def get_testCase(self):
@@ -117,8 +116,10 @@ class testExecutor():
         """
 
         server_requirements = self.current_testcase.server_requirements
+        cnf_path = self.current_testcase.cnf_path
         (self.current_servers,bad_start) = self.server_manager.request_servers( self.name
                                                               , self.workdir
+                                                              , cnf_path
                                                               , server_requirements
                                                               , self.working_environment)
         if self.current_servers == 0 or bad_start:
@@ -140,6 +141,9 @@ class testExecutor():
                 variable_name = "%s_%s" %(self.name.upper(), server.name.upper())
                 variable_value = str(server.master_port)
                 extra_reqs[variable_name] = variable_value
+                variable_name = variable_name + "_PID"
+                variable_value = str(server.pid)
+                extra_reqs[variable_name] = variable_value
             self.working_environment.update(extra_reqs)
         return 
 
@@ -194,8 +198,7 @@ class testExecutor():
 
     def execute_testCase(self):
         """ Do whatever evil voodoo we must do to execute a testCase """
-        if self.verbose:
-            self.logging.verbose("Executor: %s executing test: %s" %(self.name, self.current_testcase.fullname))
+        self.logging.verbose("Executor: %s executing test: %s" %(self.name, self.current_testcase.fullname))
 
     def record_test_result(self):
         """ We get the test_manager to record the result """
@@ -220,7 +223,62 @@ class testExecutor():
             method
 
         """
-        
+
+        self.process_environment_reqs()
+        self.process_symlink_reqs()
+        self.process_master_sh()  
         return
 
+    def process_master_sh(self):
+        """ We do what we need to if we have a master.sh file """
+        if self.current_testcase.master_sh:
+            retcode, output = self.system_manager.execute_cmd("/bin/sh %s" %(self.current_testcase.master_sh))
+            self.logging.debug("retcode: %retcode")
+            self.logging.debug("%output")
+
+    def process_environment_reqs(self):
+        """ We generate the ENV vars we need set
+            and then ask systemManager to do so
+
+        """
+        # We need to have a default set / file / whatever based
+        # on the dbqp config file / what we're using dbqp for
+        # will move this dict elsewhere to make this method more generic
+
+        env_reqs = { 'DRIZZLETEST_VARDIR': self.master_server.vardir
+                   ,  'DRIZZLE_TMP_DIR': self.master_server.tmpdir
+                   ,  'MASTER_MYSOCK': self.master_server.socket_file
+                   ,  'MASTER_MYPORT': str(self.master_server.master_port)
+                   ,  'MC_PORT': str(self.master_server.mc_port)
+                   ,  'PBMS_PORT': str(self.master_server.pbms_port)
+                   ,  'JSON_SERVER_PORT': str(self.master_server.json_server_port)
+                   ,  'RABBITMQ_NODE_PORT': str(self.master_server.rabbitmq_node_port)
+                   ,  'DRIZZLE_TCP_PORT': str(self.master_server.drizzle_tcp_port)
+                   ,  'EXE_DRIZZLE': self.master_server.drizzle_client
+                   ,  'MASTER_SERVER_SLAVE_CONFIG' : self.master_server.slave_config_file
+                   ,  'DRIZZLE_DUMP': "%s --no-defaults -uroot -p%d" %( self.master_server.drizzledump
+                                                        , self.master_server.master_port)
+                   ,  'DRIZZLE_SLAP': "%s -uroot -p%d" %( self.master_server.drizzleslap
+                                                        , self.master_server.master_port)
+                   ,  'DRIZZLE_IMPORT': "%s -uroot -p%d" %( self.master_server.drizzleimport
+                                                          , self.master_server.master_port)
+                   ,  'DRIZZLE': "%s -uroot -p%d" %( self.master_server.drizzle_client
+                                                   , self.master_server.master_port)
+                   ,  'DRIZZLE_BASEDIR' : self.system_manager.code_manager.code_trees['drizzle'][0].basedir
+                   ,  'DRIZZLE_TRX_READER' : self.master_server.trx_reader
+                   ,  'DRIZZLE_TEST_WORKDIR' : self.system_manager.workdir
+                   }     
+
+        self.working_environment = self.system_manager.env_manager.create_working_environment(env_reqs)
+
+    def process_symlink_reqs(self):
+        """ Create any symlinks we may need """
+        needed_symlinks = []
+
+        self.system_manager.create_symlinks(needed_symlinks)
+
+    
+   
+
+
    
